//Microsoft Developer Studio generated resource script.
//
#include "resource.h"

// Generated Help ID header file
#define APSTUDIO_HIDDEN_SYMBOLS
#include "resource.hm"
#undef APSTUDIO_HIDDEN_SYMBOLS

#define APSTUDIO_READONLY_SYMBOLS
/////////////////////////////////////////////////////////////////////////////
//
// Generated from the TEXTINCLUDE 2 resource.
//
#include "afxres.h"

/////////////////////////////////////////////////////////////////////////////
#undef APSTUDIO_READONLY_SYMBOLS

/////////////////////////////////////////////////////////////////////////////
// English (U.K.) resources

#if !defined(AFX_RESOURCE_DLL) || defined(AFX_TARG_ENG)
#ifdef _WIN32
LANGUAGE LANG_ENGLISH, SUBLANG_ENGLISH_UK
#pragma code_page(1252)
#endif //_WIN32

#ifdef APSTUDIO_INVOKED
/////////////////////////////////////////////////////////////////////////////
//
// TEXTINCLUDE
//

1 TEXTINCLUDE DISCARDABLE 
BEGIN
    "resource.h\0"
END

2 TEXTINCLUDE DISCARDABLE 
BEGIN
    "#include ""afxres.h""\r\n"
    "\0"
END

3 TEXTINCLUDE DISCARDABLE 
BEGIN
    "#include ""res\\btqw.rc2""  // non-App Studio edited resources\r\n"
    "\r\n"
    "#include ""afxres.rc""  // Standard components\r\n"
    "\0"
END

#endif    // APSTUDIO_INVOKED


/////////////////////////////////////////////////////////////////////////////
//
// Icon
//

// Icon with lowest ID value placed first to ensure application icon
// remains consistent on all systems.
IDR_MAINFRAME           ICON    DISCARDABLE     "RES\\Btqw.ico"
IDR_VIEWJOB             ICON    DISCARDABLE     "res\\idr_view.ico"
IDR_JOBS                ICON    DISCARDABLE     "RES\\Jobs.ico"
IDR_VARS                ICON    DISCARDABLE     "RES\\Vars.ico"

/////////////////////////////////////////////////////////////////////////////
//
// Menu
//

IDR_MAINFRAME MENU PRELOAD DISCARDABLE 
BEGIN
    POPUP "&File"
    BEGIN
        MENUITEM "&Time defaults",              ID_FILE_TIMEDEFAULTS
        MENUITEM "&Condition defaults",         ID_FILE_CONDITIONDEFAULTS
        MENUITEM "&Assignment defaults",        ID_FILE_ASSIGNMENTDEFAULTS
        MENUITEM SEPARATOR
        MENUITEM "Program &Options",            ID_FILE_PROGRAMOPTIONS
        MENUITEM "Save &File",                  ID_FILE_SAVEFILE
        MENUITEM SEPARATOR
        MENUITEM "&Network Stats",              ID_FILE_NETWORKSTATS
        MENUITEM "User &Perms",                 ID_FILE_USERPERMS
        MENUITEM SEPARATOR
        MENUITEM "E&xit",                       ID_APP_EXIT
    END
    POPUP "&Window"
    BEGIN
        MENUITEM "New &Job Window",             ID_WINDOW_NEWJOBWINDOW
        MENUITEM "New &Variable Window",        ID_WINDOW_NEWVARWINDOW
        MENUITEM "Window &Options",             ID_WINDOW_WINDOWOPTIONS
        MENUITEM "&Cascade",                    ID_WINDOW_CASCADE
        MENUITEM "Tile &Horizontally",          ID_WINDOW_TILE_HORZ
        MENUITEM "&Tile Vertically",            ID_WINDOW_TILE_VERT
        MENUITEM "&Arrange Icons",              ID_WINDOW_ARRANGE
        MENUITEM SEPARATOR
        MENUITEM "Job display &Format",         ID_WINDOW_JOBDISPLAYFORMAT
        POPUP "Job Colo&urs"
        BEGIN
            POPUP "&Program (new windows)"
            BEGIN
                MENUITEM "&Ready",                      ID_JCOLOUR_READY
                MENUITEM "&Startup",                    ID_JCOLOUR_STARTUP
                MENUITEM "R&unning",                    ID_JCOLOUR_RUNNING
                MENUITEM "&Finished",                   ID_JCOLOUR_FINISHED
                MENUITEM "&Error",                      ID_JCOLOUR_ERROR
                MENUITEM "&Abort",                      ID_JCOLOUR_ABORT
                MENUITEM "&Cancelled",                  ID_JCOLOUR_CANCELLED
            END
            POPUP "&Current job window"
            BEGIN
                MENUITEM "Ready",                       ID_WJCOLOUR_READY
                MENUITEM "&Startup",                    ID_WJCOLOUR_STARTUP
                MENUITEM "R&unning",                    ID_WJCOLOUR_RUNNING
                MENUITEM "&Finished",                   ID_WJCOLOUR_FINISHED
                MENUITEM "&Error",                      ID_WJCOLOUR_ERROR
                MENUITEM "&Abort",                      ID_WJCOLOUR_ABORT
                MENUITEM "&Cancelled",                  ID_WJCOLOUR_CANCELLED

            END
            MENUITEM "Copy to &Application",        ID_FILE_JCOLOUR_COPYTOPROG

            MENUITEM "Copy to &Window",             ID_FILE_JCOLOUR_COPYTOWIN

        END
        MENUITEM "Va&r display fmt",            ID_WINDOW_VARDISPLAYFMTLINE1
        MENUITEM "&Save widths as default",     ID_WINDOW_SAVEWIDTHSASDEFAULT

    END
    POPUP "&Action"
    BEGIN
        MENUITEM "&Delete job\tDEL",            ID_ACTION_DELETEJOB
        MENUITEM "&Permissions",                ID_ACTION_PERMISSIONS
        MENUITEM "&Title pri/loadlev\tp",       ID_ACTION_TITLEPRILOADLEV
        MENUITEM "Set &runnable",               ID_ACTION_SETRUNNABLE
        MENUITEM "Set &cancelled",              ID_ACTION_SETCANCELLED
        MENUITEM "&Force run",                  ID_ACTION_FORCERUN
        MENUITEM "&Go job",                     ID_ACTION_GOJOB
        MENUITEM "&Interrupt job\tCtrl-C",      ID_ACTION_KILLJOB
        MENUITEM "&Quit job\tCtrl-\\",          ID_ACTION_QUITJOB
        MENUITEM "&Other signal",               ID_ACTION_OTHERSIGNAL
    END
    POPUP "&Jobs"
    BEGIN
        MENUITEM "&View job",                   ID_JOBS_VIEWJOB
        MENUITEM "&Advance Time\t>",            ID_JOBS_ADVANCETIME
        MENUITEM "&Time\tt",                    ID_JOBS_TIME
        MENUITEM "&Process parameters",         ID_JOBS_PROCPARAM
        MENUITEM "Time &Limits",                ID_JOBS_TIMELIMITS
        MENUITEM "&Mail and write",             ID_JOBS_MAIL
        MENUITEM "&Arguments",                  ID_JOBS_ARGUMENTS
        MENUITEM "&Environment",                ID_JOBS_ENVIRONMENT
        MENUITEM "&Redirections",               ID_JOBS_REDIRECTIONS
        MENUITEM SEPARATOR
        MENUITEM "&Unqueue job",                ID_JOBS_UNQUEUEJOB
        MENUITEM "&Copy job",                   ID_JOBS_COPYJOB
        MENUITEM "Copy &options in job",        ID_JOBS_COPYOPTIONSINJOB
        MENUITEM SEPARATOR
        MENUITEM "&Invoke BTRW",                ID_JOBS_INVOKEBTRW
    END
    POPUP "&Conditions"
    BEGIN
        MENUITEM "Job &Conditions",             ID_CONDITIONS_JOBCONDITIONS
        MENUITEM "Job &Assignments",            ID_CONDITIONS_JOBASSIGNMENTS
    END
    POPUP "&Variables"
    BEGIN
        MENUITEM "&Assign\t=",                  ID_VARIABLES_ASSIGN
        MENUITEM "&Increment\t+",               ID_VARIABLES_INCREMENT
        MENUITEM "&Decrement\t-",               ID_VARIABLES_DECREMENT
        MENUITEM "&Multiply\t*",                ID_VARIABLES_MULTIPLY
        MENUITEM "&Divide\t/",                  ID_VARIABLES_DIVIDE
        MENUITEM "&Remainder\t%",               ID_VARIABLES_REMAINDER
        MENUITEM SEPARATOR
        MENUITEM "Set &comment",                ID_VARIABLES_SETCOMMENT
        MENUITEM SEPARATOR
        MENUITEM "&Set constant\t@",            ID_VARIABLES_SETCONSTANT
    END
    POPUP "&Search"
    BEGIN
        MENUITEM "&Search for....",             ID_SEARCH_SEARCHFOR
        MENUITEM "Search &Forward\tF3",         ID_SEARCH_SEARCHFORWARD
        , GRAYED
        MENUITEM "Search &Backwards\tF4",       ID_SEARCH_SEARCHBACKWARDS
        , GRAYED
    END
    POPUP "&View"
    BEGIN
        MENUITEM "Show &Toolbar",               ID_VIEW_TOOLBAR
        MENUITEM "Show &Status Bar",            ID_VIEW_STATUS_BAR
    END
    POPUP "&Help"
    BEGIN
        MENUITEM "&Index",                      ID_HELP_INDEX
        MENUITEM "&Using Help",                 ID_HELP_USING
        MENUITEM SEPARATOR
        MENUITEM "&About BTQW...",              ID_APP_ABOUT
    END
END

IDR_JOBFLOAT MENU DISCARDABLE 
BEGIN
    POPUP ""
    BEGIN
        MENUITEM "Set &runnable",               ID_ACTION_SETRUNNABLE
        MENUITEM "Set &cancelled",              ID_ACTION_SETCANCELLED
        MENUITEM "&Kill job",                   ID_ACTION_KILLJOB
        MENUITEM SEPARATOR
        MENUITEM "Set C&onditions",             ID_CONDITIONS_JOBCONDITIONS
        MENUITEM "Set &Assignments",            ID_CONDITIONS_JOBASSIGNMENTS
        MENUITEM SEPARATOR
        MENUITEM "&View Job",                   ID_JOBS_VIEWJOB
    END
END

IDR_VARFLOAT MENU DISCARDABLE 
BEGIN
    POPUP ""
    BEGIN
        MENUITEM "&Assign variable",            ID_VARIABLES_ASSIGN
        MENUITEM "&Increment Variable",         ID_VARIABLES_INCREMENT
        MENUITEM "&Decrement Variable",         ID_VARIABLES_DECREMENT
        MENUITEM SEPARATOR
        MENUITEM "Set &Constant",               ID_VARIABLES_SETCONSTANT
        MENUITEM SEPARATOR
        MENUITEM "&Set comment",                ID_VARIABLES_SETCOMMENT
    END
END


/////////////////////////////////////////////////////////////////////////////
//
// Accelerator
//

IDR_MAINFRAME ACCELERATORS PRELOAD MOVEABLE PURE 
BEGIN
    """",           ID_VARIABLES_SETCOMMENT, ASCII, NOINVERT
    "%",            ID_VARIABLES_REMAINDER, ASCII,  NOINVERT
    "*",            ID_VARIABLES_MULTIPLY,  ASCII,  NOINVERT
    "+",            ID_VARIABLES_INCREMENT, ASCII,  NOINVERT
    "-",            ID_VARIABLES_DECREMENT, ASCII,  NOINVERT
    "/",            ID_VARIABLES_DIVIDE,    ASCII,  NOINVERT
    "=",            ID_VARIABLES_ASSIGN,    ASCII,  NOINVERT
    ">",            ID_JOBS_ADVANCETIME,    ASCII,  NOINVERT
    "@",            ID_VARIABLES_SETCONSTANT, ASCII, NOINVERT
    "A",            ID_CONDITIONS_JOBASSIGNMENTS, VIRTKEY, NOINVERT
    "C",            ID_CONDITIONS_JOBCONDITIONS, VIRTKEY, NOINVERT
    "C",            ID_ACTION_KILLJOB,      VIRTKEY, CONTROL, NOINVERT
    "C",            ID_ACTION_SETCANCELLED, VIRTKEY, SHIFT, NOINVERT
    "F",            ID_ACTION_FORCERUN,     VIRTKEY, SHIFT, NOINVERT
    "G",            ID_ACTION_GOJOB,        VIRTKEY, SHIFT, NOINVERT
    "P",            ID_ACTION_TITLEPRILOADLEV, VIRTKEY, NOINVERT
    "R",            ID_ACTION_SETRUNNABLE,  VIRTKEY, NOINVERT
    "T",            ID_JOBS_TIME,           VIRTKEY, NOINVERT
    VK_DELETE,      ID_ACTION_DELETEJOB,    VIRTKEY, NOINVERT
    VK_F1,          ID_HELP,                VIRTKEY, NOINVERT
    VK_F3,          ID_SEARCH_SEARCHFORWARD, VIRTKEY, NOINVERT
    VK_F4,          ID_SEARCH_SEARCHBACKWARDS, VIRTKEY, NOINVERT
END


/////////////////////////////////////////////////////////////////////////////
//
// Dialog
//

IDD_ABOUTBOX DIALOG DISCARDABLE  34, 22, 217, 55
STYLE DS_MODALFRAME | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "About BTQW"
FONT 8, "MS Sans Serif"
BEGIN
    ICON            IDR_MAINFRAME,IDC_STATIC,11,17,20,20
    CTEXT           "BTQW Version 6.20",IDC_STATIC,40,10,119,8
    CTEXT           "Copyright © Xi Software Ltd 2004",IDC_STATIC,40,27,119,
                    8
    DEFPUSHBUTTON   "OK",IDOK,176,6,32,14,WS_GROUP
    CTEXT           "Revised 3 January 2004",IDC_STATIC,40,44,119,8
END

IDD_TIMER DIALOGEX 0, 0, 287, 246
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Set job time"
FONT 8, "MS Sans Serif", 0, 0, 0x1
BEGIN
    CONTROL         "Set time for job",IDC_TIMEISSET,"Button",
                    BS_AUTOCHECKBOX | WS_TABSTOP,12,8,92,10,0,HIDC_TIMEISSET
    EDITTEXT        IDC_HOUR,7,24,31,14,ES_READONLY | ES_NUMBER,0,HIDC_HOUR
    CONTROL         "Spin1",IDC_SCR_HOUR,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,33,24,9,14,0,HIDC_SCR_HOUR
    LTEXT           ":",IDC_COLON,44,27,2,8,0,0,HIDC_COLON
    EDITTEXT        IDC_MIN,48,24,31,14,ES_READONLY | ES_NUMBER,0,HIDC_MIN
    CONTROL         "Spin2",IDC_SCR_MIN,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,74,24,9,14,0,HIDC_SCR_MIN
    EDITTEXT        IDC_WDAY,91,24,54,14,ES_READONLY,0,HIDC_WDAY
    CONTROL         "Spin7",IDC_SCR_WDAY,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,137,24,9,14,0,
                    HIDC_SCR_WDAY
    EDITTEXT        IDC_MDAY,147,24,31,14,ES_READONLY,0,HIDC_MDAY
    CONTROL         "Spin8",IDC_SCR_MDAY,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,167,24,9,14,0,
                    HIDC_SCR_MDAY
    EDITTEXT        IDC_MON,180,24,64,14,ES_READONLY,0,HIDC_MON
    CONTROL         "Spin9",IDC_SCR_MON,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,235,24,9,14,0,HIDC_SCR_MON
    EDITTEXT        IDC_YEAR,246,24,31,14,ES_READONLY,0,HIDC_YEAR
    CONTROL         "Spin10",IDC_SCR_YEAR,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,271,24,9,14,0,
                    HIDC_SCR_YEAR
    CONTROL         "Run and delete",IDC_DELETE,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,80,40,76,10,0,HIDC_DELETE
    CONTROL         "Run and retain",IDC_RETAIN,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,80,52,84,10,0,HIDC_RETAIN
    GROUPBOX        "Repeat every",IDC_MESS_REPEATEVERY,12,60,156,100
    EDITTEXT        IDC_REPEAT,19,83,34,12,ES_AUTOHSCROLL | ES_NUMBER,0,
                    HIDC_REPEAT
    CONTROL         "Spin1",IDC_SCR_REPEAT,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,57,82,9,14,0,HIDC_SCR_REPEAT
    CONTROL         "Minutes",IDC_REPMINS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,80,72,40,10,0,HIDC_REPMINS
    CONTROL         "Hours",IDC_REPHOURS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,80,84,34,10,0,HIDC_REPHOURS
    CONTROL         "Days",IDC_REPDAYS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,80,96,34,10,0,HIDC_REPDAYS
    CONTROL         "Weeks",IDC_REPWEEKS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,80,108,34,10,0,HIDC_REPWEEKS
    CONTROL         "Months (rel begin)",IDC_REPMONTHSB,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,80,120,72,10,0,
                    HIDC_REPMONTHSB
    CONTROL         "Months (rel end)",IDC_REPMONTHSE,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,80,132,76,10,0,
                    HIDC_REPMONTHSE
    CONTROL         "Years",IDC_REPYEARS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,80,144,34,10,0,HIDC_REPYEARS
    LTEXT           "Month day",IDC_MONDAYNAME,24,108,44,8
    EDITTEXT        IDC_MONTHDAY,19,131,34,12,ES_AUTOHSCROLL | ES_NUMBER,0,
                    HIDC_MONTHDAY
    CONTROL         "Spin2",IDC_SCR_MONTHDAY,"msctls_updown32",
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS,57,130,9,
                    14,0,HIDC_SCR_MONTHDAY
    GROUPBOX        "Avoiding...",IDC_MESS_AVOIDING,172,60,96,60
    CONTROL         "Sun",IDC_AVSUN,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    176,72,34,10,0,HIDC_AVSUN
    CONTROL         "Mon",IDC_AVMON,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    176,85,34,8,0,HIDC_AVMON
    CONTROL         "Tue",IDC_AVTUE,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    176,96,34,10,0,HIDC_AVTUE
    CONTROL         "Wed",IDC_AVWED,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    176,108,34,10,0,HIDC_AVWED
    CONTROL         "Thur",IDC_AVTHU,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    220,72,34,10,0,HIDC_AVTHU
    CONTROL         "Fri",IDC_AVFRI,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    220,84,34,10,0,HIDC_AVFRI
    CONTROL         "Sat",IDC_AVSAT,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    220,96,34,10,0,HIDC_AVSAT
    CONTROL         "Holiday",IDC_AVHOLIDAY,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,220,108,40,10,0,HIDC_AVHOLIDAY
    LTEXT           "Next repeat comes to....",IDC_MESS_COMESTO,148,168,88,8
    EDITTEXT        IDC_REPRESULT,120,184,144,12,ES_AUTOHSCROLL | 
                    ES_READONLY,0,HIDC_REPRESULT
    GROUPBOX        "If not possible",IDC_MESS_NOTPOSS,12,164,83,76
    CONTROL         "Skip",IDC_NPSKIP,"Button",BS_AUTORADIOBUTTON | WS_GROUP | 
                    WS_TABSTOP,16,180,34,10,0,HIDC_NPSKIP
    CONTROL         "Delay Current",IDC_NPDELCURR,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,16,194,72,10,0,
                    HIDC_NPDELCURR
    CONTROL         "Delay all",IDC_NPDELALL,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,16,208,57,10,0,HIDC_NPDELALL
    CONTROL         "Catch up",IDC_NPCATCHUP,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,16,222,57,10,0,HIDC_NPCATCHUP
    DEFPUSHBUTTON   "OK",IDOK,120,204,40,14
    PUSHBUTTON      "Cancel",IDCANCEL,224,204,40,14
END

IDD_TITLEPRIO DIALOGEX 6, 18, 171, 135
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Title Command Int Priority Load level"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Title",IDC_STATIC,8,12,29,8
    EDITTEXT        IDC_TITLE,72,8,72,12,ES_AUTOHSCROLL,0,HIDC_TITLE
    LTEXT           "Command Interp",IDC_STATIC,8,32,56,8
    COMBOBOX        IDC_CMDINTERP,72,28,72,36,CBS_DROPDOWNLIST | 
                    CBS_AUTOHSCROLL | CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,
                    HIDC_CMDINTERP
    LTEXT           "Priority",IDC_STATIC,8,56,26,8
    EDITTEXT        IDC_PRIORITY,72,52,30,12,ES_NUMBER,0,HIDC_PRIORITY
    CONTROL         "Spin1",IDC_SCR_PRIORITY,"msctls_updown32",
                    UDS_SETBUDDYINT | UDS_ALIGNRIGHT | UDS_AUTOBUDDY | 
                    UDS_ARROWKEYS | UDS_NOTHOUSANDS,110,51,10,14,0,
                    HIDC_SCR_PRIORITY
    LTEXT           "Load level",IDC_STATIC,8,84,42,8
    EDITTEXT        IDC_LOADLEV,72,80,30,12,ES_NUMBER,0,HIDC_LOADLEV
    CONTROL         "Spin2",IDC_SCR_LOADLEV,"msctls_updown32",
                    UDS_SETBUDDYINT | UDS_ALIGNRIGHT | UDS_AUTOBUDDY | 
                    UDS_ARROWKEYS | UDS_NOTHOUSANDS,110,80,10,14,0,
                    HIDC_SCR_LOADLEV
    DEFPUSHBUTTON   "OK",IDOK,12,108,40,14
    PUSHBUTTON      "Cancel",IDCANCEL,120,108,40,14
END

IDD_SEARCHDATA DIALOGEX 0, 0, 237, 78
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Search job data"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Search",IDC_STATIC,8,20,30,7
    EDITTEXT        IDC_LOOKFOR,44,17,126,12,ES_AUTOHSCROLL,0,HIDC_LOOKFOR
    GROUPBOX        "",IDC_STATIC,0,35,52,39,NOT WS_VISIBLE
    CONTROL         "Forward",IDC_SEARCH_FORWARD,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP,5,45,39,10,0,HIDC_SEARCH_FORWARD
    CONTROL         "Backward",IDC_SEARCH_BACK,"Button",BS_AUTORADIOBUTTON,5,
                    60,45,10,0,HIDC_SEARCH_BACK
    CONTROL         "Wrap Around",IDC_WRAPROUND,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,65,45,60,10,0,HIDC_WRAPROUND
    CONTROL         "Ignore Case",IDC_IGNORECASE,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,65,60,75,10,0,HIDC_IGNORECASE
    LTEXT           ". = wild card",IDC_STATIC,140,52,44,7
    DEFPUSHBUTTON   "OK",IDOK,196,8,34,12
    PUSHBUTTON      "Cancel",IDCANCEL,196,29,34,12
END

IDD_SEARCHJ DIALOGEX 0, 0, 180, 99
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Search for job strings"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Search",IDC_STATIC,10,15,30,7
    EDITTEXT        IDC_LOOKFOR,48,12,126,12,ES_AUTOHSCROLL,0,HIDC_LOOKFOR
    CONTROL         "Forward",IDC_SEARCH_FORWARD,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP,15,40,65,10,0,HIDC_SEARCH_FORWARD
    CONTROL         "Backward",IDC_SEARCH_BACK,"Button",BS_AUTORADIOBUTTON,
                    15,55,50,8,0,HIDC_SEARCH_BACK
    CONTROL         "Wrap Around",IDC_WRAPROUND,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,15,70,65,10,0,HIDC_WRAPROUND
    CONTROL         "User",IDC_SRCH_USER,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,85,40,34,10,0,HIDC_SRCH_USER
    CONTROL         "Job title",IDC_SRCH_JTITLE,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,85,55,50,9,0,HIDC_SRCH_JTITLE
    DEFPUSHBUTTON   "OK",IDOK,136,36,35,14
    PUSHBUTTON      "Cancel",IDCANCEL,136,66,35,14
END

IDD_PROGOPTS DIALOGEX 0, 0, 204, 191
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Program options"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Job queue",IDC_STATIC,8,12,52,8
    COMBOBOX        IDC_JOBQUEUE,64,10,73,46,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_JOBQUEUE
    CONTROL         "Including empty",IDC_INCNULL,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,144,12,56,10,0,HIDC_INCNULL
    LTEXT           "Display only user",IDC_STATIC,8,32,60,8
    COMBOBOX        IDC_USER,77,30,60,48,CBS_DROPDOWN | CBS_SORT | 
                    WS_VSCROLL | WS_TABSTOP,0,HIDC_USER
    LTEXT           "Display only group",IDC_STATIC,8,52,60,8
    COMBOBOX        IDC_GROUP,77,50,60,52,CBS_DROPDOWN | CBS_SORT | 
                    WS_VSCROLL | WS_TABSTOP,0,HIDC_GROUP
    GROUPBOX        "Confirm delete jobs",IDC_STATIC,4,68,80,40
    CONTROL         "Never",IDC_NEVER,"Button",BS_AUTORADIOBUTTON | WS_GROUP | 
                    WS_TABSTOP,8,80,35,10,0,HIDC_NEVER
    CONTROL         "Always",IDC_ALWAYS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,8,92,56,10,0,HIDC_ALWAYS
    GROUPBOX        "Host offline",IDC_STATIC,92,68,58,40
    CONTROL         "Ignore",IDC_PROBE_IGNORE,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,100,80,35,10,0,HIDC_PROBE_IGNORE
    CONTROL         "Warn",IDC_PROBE_WARN,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,100,92,32,10,0,HIDC_PROBE_WARN
    GROUPBOX        "Host display",IDC_STATIC,4,116,93,46
    CONTROL         "Display local host only",IDC_LOCALONLY,"Button",
                    BS_AUTORADIOBUTTON | WS_GROUP | WS_TABSTOP,8,128,80,10,0,
                    HIDC_LOCALONLY
    CONTROL         "Display all hosts",IDC_DISPALL,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,8,144,76,10,0,
                    HIDC_DISPALL
    LTEXT           "Polling",IDC_STATIC,112,120,28,8
    EDITTEXT        IDC_POLLTIME,112,132,32,14,ES_AUTOHSCROLL | ES_NUMBER,0,
                    HIDC_POLLTIME
    CONTROL         "Spin1",IDC_SCR_POLLTIME,"msctls_updown32",
                    UDS_SETBUDDYINT | UDS_ALIGNRIGHT | UDS_AUTOBUDDY | 
                    UDS_ARROWKEYS | UDS_NOTHOUSANDS,144,134,10,14,0,
                    HIDC_SCR_POLLTIME
    LTEXT           "Millisec",IDC_STATIC,156,135,29,8
    CONTROL         "Unqueue as binary",IDC_BINUNQ,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,112,152,72,10,0,HIDC_BINUNQ
    GROUPBOX        "Job control files",IDC_STATIC,12,164,176,24
    CONTROL         "XBC",IDC_SJXBC,"Button",BS_AUTORADIOBUTTON | WS_GROUP | 
                    WS_TABSTOP,24,176,35,10,0,HIDC_SJXBC
    CONTROL         "BAT",IDC_SJBAT,"Button",BS_AUTORADIOBUTTON | WS_TABSTOP,
                    98,176,35,10,0,HIDC_SJBAT
    DEFPUSHBUTTON   "OK",IDOK,160,32,35,14
    PUSHBUTTON      "Cancel",IDCANCEL,160,55,35,14
END

IDD_JCOND DIALOGEX 0, 0, 224, 111
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job conditions"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LISTBOX         IDC_CONDLIST,4,8,182,68,LBS_USETABSTOPS | 
                    LBS_NOINTEGRALHEIGHT | WS_VSCROLL | WS_HSCROLL | 
                    WS_TABSTOP,0,HIDC_CONDLIST
    PUSHBUTTON      "New",IDC_NEWCOND,192,8,28,14,0,0,HIDC_NEWCOND
    PUSHBUTTON      "Edit",IDC_EDITCOND,192,35,28,14,0,0,HIDC_EDITCOND
    PUSHBUTTON      "Delete",IDC_CONDDEL,192,62,28,14,0,0,HIDC_CONDDEL
    DEFPUSHBUTTON   "OK",IDOK,8,88,36,14
    PUSHBUTTON      "Cancel",IDCANCEL,184,88,36,14
END

IDD_EDITCOND DIALOGEX 0, 0, 196, 124
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Edit condition"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    COMBOBOX        IDC_CONDVAR,8,8,64,48,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_CONDVAR
    LTEXT           "Variable",IDC_STATIC,80,12,31,8
    EDITTEXT        IDC_VALUE,8,32,88,13,ES_AUTOHSCROLL,0,HIDC_VALUE
    CONTROL         "Spin1",IDC_SCR_VALUE,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,99,31,10,14,0,
                    HIDC_SCR_VALUE
    LTEXT           "Value",IDC_STATIC,120,34,31,8
    GROUPBOX        "Comparison",IDC_STATIC,8,60,57,57
    CONTROL         "=",IDC_CEQ,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_GROUP | WS_TABSTOP,20,72,15,10,0,HIDC_CEQ
    CONTROL         "!=",IDC_CNE,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,20,88,15,10,0,HIDC_CNE
    CONTROL         "<",IDC_CLT,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,20,104,15,10,0,HIDC_CLT
    CONTROL         "<=",IDC_CLE,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,40,72,15,10,0,HIDC_CLE
    CONTROL         ">",IDC_CGT,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,40,88,15,10,0,HIDC_CGT
    CONTROL         ">=",IDC_CGE,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,40,104,15,10,0,HIDC_CGE
    GROUPBOX        "If host unavailable",IDC_STATIC,84,76,76,40
    CONTROL         "Ignore",IDC_CNOTCRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,88,88,35,10,0,HIDC_CNOTCRIT
    CONTROL         "Hold job",IDC_CCRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,88,100,60,10,0,HIDC_CCRIT
    DEFPUSHBUTTON   "OK",IDOK,156,7,35,14
    PUSHBUTTON      "Cancel",IDCANCEL,156,31,35,14
END

IDD_JASS DIALOGEX 0, 0, 236, 143
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job Assignments"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LISTBOX         IDC_ASSLIST,8,8,176,84,LBS_USETABSTOPS | 
                    LBS_NOINTEGRALHEIGHT | WS_VSCROLL | WS_HSCROLL | 
                    WS_TABSTOP,0,HIDC_ASSLIST
    PUSHBUTTON      "New",IDC_NEWASS,192,8,36,17,0,0,HIDC_NEWASS
    PUSHBUTTON      "Edit",IDC_EDITASS,192,41,36,17,0,0,HIDC_EDITASS
    PUSHBUTTON      "Delete",IDC_ASSDEL,192,74,36,17,0,0,HIDC_ASSDEL
    DEFPUSHBUTTON   "OK",IDOK,8,108,46,17
    PUSHBUTTON      "Cancel",IDCANCEL,182,108,46,17
END

IDD_EDITASS DIALOGEX 0, 0, 236, 171
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Edit Assignment"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Variable",IDC_STATIC,32,4,30,8
    LTEXT           "Value",IDC_STATIC,144,4,30,8
    COMBOBOX        IDC_ASSVAR,12,20,82,64,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_ASSVAR
    EDITTEXT        IDC_VALUE,104,20,116,12,ES_AUTOHSCROLL,0,HIDC_VALUE
    CONTROL         "Spin1",IDC_SCR_VALUE,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,222,19,10,14,0,
                    HIDC_SCR_VALUE
    GROUPBOX        "Assignment type",IDC_STATIC,12,40,100,70
    CONTROL         "Set",IDC_ASET,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_GROUP | WS_TABSTOP,27,55,19,12,0,HIDC_ASET
    CONTROL         "+",IDC_AADD,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,27,74,19,12,0,HIDC_AADD
    CONTROL         "-",IDC_ASUB,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,27,94,19,12,0,HIDC_ASUB
    CONTROL         "X",IDC_AMULT,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,53,55,19,12,0,HIDC_AMULT
    CONTROL         "/",IDC_ADIV,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,53,74,19,12,0,HIDC_ADIV
    CONTROL         "Md",IDC_AMOD,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,53,94,19,12,0,HIDC_AMOD
    CONTROL         "Exit",IDC_AEXIT,"Button",BS_AUTORADIOBUTTON | 
                    BS_LEFTTEXT | WS_TABSTOP,76,55,27,12,0,HIDC_AEXIT
    CONTROL         "Sig",IDC_ASIGNAL,"Button",BS_AUTORADIOBUTTON | 
                    BS_LEFTTEXT | WS_TABSTOP,76,74,27,12,0,HIDC_ASIGNAL
    GROUPBOX        "If host unavailable",IDC_STATIC,12,116,98,49
    CONTROL         "Ignore",IDC_ANOTCRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,17,131,45,12,0,HIDC_ANOTCRIT
    CONTROL         "Hold job",IDC_ACRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,17,146,77,12,0,HIDC_ACRIT
    CONTROL         "On start",IDC_ASTART,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,136,52,36,9,0,HIDC_ASTART
    CONTROL         "REVERSE on exit",IDC_AREVERSE,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,136,65,66,10,0,HIDC_AREVERSE
    CONTROL         "Normal exit",IDC_ANORMAL,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,136,79,47,8,0,HIDC_ANORMAL
    CONTROL         "Error exit",IDC_AERROR,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,136,91,47,10,0,HIDC_AERROR
    CONTROL         "Abort",IDC_AABORT,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    136,105,47,10,0,HIDC_AABORT
    CONTROL         "Cancel",IDC_ACANCEL,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,136,119,47,10,0,HIDC_ACANCEL
    DEFPUSHBUTTON   "OK",IDOK,130,145,45,17
    PUSHBUTTON      "Cancel",IDCANCEL,185,145,45,17
END

IDD_MAILWRITE DIALOGEX 0, 0, 140, 55
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Mail/Write flags"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    CONTROL         "Mail completion",IDC_MAIL,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,8,8,56,9,0,HIDC_MAIL
    CONTROL         "Write completion",IDC_WRITE,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,8,28,68,10,0,HIDC_WRITE
    DEFPUSHBUTTON   "OK",IDOK,98,6,33,11
    PUSHBUTTON      "Cancel",IDCANCEL,98,28,33,11
END

IDD_PROCPAR DIALOGEX 0, 0, 248, 171
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Process parameters"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Directory",IDC_STATIC,8,16,30,8
    EDITTEXT        IDC_DIRECTORY,52,13,164,13,ES_AUTOHSCROLL,0,
                    HIDC_DIRECTORY
    LTEXT           "Umask - turn OFF",IDC_STATIC,8,44,56,8
    LTEXT           "User",IDC_STATIC,72,32,20,8
    CONTROL         "R",IDC_UR,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,72,44,16,10,0,HIDC_UR
    CONTROL         "W",IDC_UW,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,72,56,16,10,0,HIDC_UW
    CONTROL         "X",IDC_UX,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,72,68,16,10,0,HIDC_UX
    LTEXT           "Group",IDC_STATIC,104,32,20,8
    CONTROL         "R",IDC_GR,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,104,44,16,10,0,HIDC_GR
    CONTROL         "W",IDC_GW,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,104,56,16,10,0,HIDC_GW
    CONTROL         "X",IDC_GX,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,104,68,16,10,0,HIDC_GX
    LTEXT           "Others",IDC_STATIC,132,32,20,8
    CONTROL         "R",IDC_OR,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,132,44,16,10,0,HIDC_OR
    CONTROL         "W",IDC_OW,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,132,56,16,10,0,HIDC_OW
    CONTROL         "X",IDC_OX,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,132,68,16,10,0,HIDC_OX
    LTEXT           "Ulimit",IDC_STATIC,172,32,30,8
    EDITTEXT        IDC_ULIMIT,155,52,39,10,0,0,HIDC_ULIMIT
    CONTROL         "Spin1",IDC_SCR_ULIMIT,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,199,51,8,12,0,
                    HIDC_SCR_ULIMIT
    LTEXT           "Normal exit",IDC_STATIC,8,86,36,8
    EDITTEXT        IDC_NEXITL,56,85,22,11,ES_READONLY | ES_NUMBER,0,
                    HIDC_NEXITL
    CONTROL         "Spin2",IDC_SCR_NEXITL,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,76,84,7,12,0,HIDC_SCR_NEXITL
    LTEXT           "to",IDC_STATIC,87,86,12,8
    EDITTEXT        IDC_NEXITU,102,85,22,10,ES_READONLY | ES_NUMBER,0,
                    HIDC_NEXITU
    CONTROL         "Spin3",IDC_SCR_NEXITU,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,121,84,7,12,0,HIDC_SCR_NEXITU
    LTEXT           "Error exit",IDC_STATIC,8,106,36,8
    EDITTEXT        IDC_EEXITL,56,105,22,10,ES_READONLY | ES_NUMBER,0,
                    HIDC_EEXITL
    CONTROL         "Spin4",IDC_SCR_EEXITL,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,77,104,7,12,0,HIDC_SCR_EEXITL
    LTEXT           "to",IDC_STATIC,87,106,12,8
    EDITTEXT        IDC_EEXITU,102,105,22,10,ES_READONLY | ES_NUMBER,0,
                    HIDC_EEXITU
    CONTROL         "Spin5",IDC_SCR_EEXITU,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,124,104,7,12,0,HIDC_SCR_EEXITU
    GROUPBOX        "After error",IDC_STATIC,138,80,105,40
    CONTROL         "Advance time",IDC_ADVTERR,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,144,92,56,10,0,HIDC_ADVTERR
    CONTROL         "Do not advance time",IDC_NADVTERR,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,144,104,76,10,0,
                    HIDC_NADVTERR
    CONTROL         "Remote executable",IDC_REMRUNNABLE,"Button",
                    BS_AUTOCHECKBOX | WS_TABSTOP,72,128,84,10,0,
                    HIDC_REMRUNNABLE
    DEFPUSHBUTTON   "OK",IDOK,16,144,36,14
    PUSHBUTTON      "Cancel",IDCANCEL,190,144,36,14
END

IDD_ARGLIST DIALOGEX 0, 0, 232, 131
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job Argument List"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LISTBOX         IDC_ARGLIST,12,16,172,72,LBS_USETABSTOPS | 
                    LBS_NOINTEGRALHEIGHT | WS_VSCROLL | WS_HSCROLL | 
                    WS_TABSTOP,0,HIDC_ARGLIST
    PUSHBUTTON      "New",IDC_NEWARG,192,12,35,14,0,0,HIDC_NEWARG
    PUSHBUTTON      "Edit",IDC_EDITARG,192,43,35,14,0,0,HIDC_EDITARG
    PUSHBUTTON      "Delete",IDC_DELARG,192,74,35,14,0,0,HIDC_DELARG
    DEFPUSHBUTTON   "OK",IDOK,12,108,35,14
    PUSHBUTTON      "Cancel",IDCANCEL,192,108,35,14
END

IDD_EDITARG DIALOGEX 0, 0, 184, 63
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Edit Argument"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    EDITTEXT        IDC_ARGVAL,4,12,176,13,ES_AUTOHSCROLL,0,HIDC_ARGVAL
    DEFPUSHBUTTON   "OK",IDOK,4,40,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,130,40,50,14
END

IDD_ENVLIST DIALOGEX 0, 0, 335, 186
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job environment variables"
FONT 8, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LISTBOX         IDC_ENVLIST,4,12,269,124,LBS_USETABSTOPS | 
                    LBS_NOINTEGRALHEIGHT | WS_VSCROLL | WS_HSCROLL | 
                    WS_TABSTOP,0,HIDC_ENVLIST
    PUSHBUTTON      "New",IDC_NEWENV,284,12,45,17,0,0,HIDC_NEWENV
    PUSHBUTTON      "Edit",IDC_EDITENV,284,65,45,17,0,0,HIDC_EDITENV
    PUSHBUTTON      "Delete",IDC_DELENV,284,118,45,17,0,0,HIDC_DELENV
    DEFPUSHBUTTON   "OK",IDOK,4,156,45,17
    PUSHBUTTON      "Cancel",IDCANCEL,284,156,45,17
END

IDD_EDITENV DIALOGEX 0, 0, 268, 75
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Edit environment variable"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Name",IDC_STATIC,4,12,34,8
    EDITTEXT        IDC_ENAME,44,9,40,13,ES_AUTOHSCROLL,0,HIDC_ENAME
    LTEXT           "Value",IDC_STATIC,4,32,33,9
    EDITTEXT        IDC_EVALUE,44,30,220,12,ES_AUTOHSCROLL,0,HIDC_EVALUE
    DEFPUSHBUTTON   "OK",IDOK,4,52,34,14
    PUSHBUTTON      "Cancel",IDCANCEL,230,52,34,14
END

IDD_REDIRLIST DIALOGEX 0, 0, 272, 159
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job redirections"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LISTBOX         IDC_REDIRLIST,3,10,209,101,LBS_USETABSTOPS | 
                    LBS_NOINTEGRALHEIGHT | WS_VSCROLL | WS_HSCROLL | 
                    WS_TABSTOP,0,HIDC_REDIRLIST
    DEFPUSHBUTTON   "New",IDC_NEWREDIR,221,10,35,14,0,0,HIDC_NEWREDIR
    DEFPUSHBUTTON   "Edit",IDC_EDITREDIR,221,53,35,14,0,0,HIDC_EDITREDIR
    DEFPUSHBUTTON   "Delete",IDC_DELREDIR,221,96,35,14,0,0,HIDC_DELREDIR
    DEFPUSHBUTTON   "OK",IDOK,3,127,35,14
    PUSHBUTTON      "Cancel",IDCANCEL,221,127,35,14
END

IDD_EDITREDIR DIALOGEX 0, 0, 260, 143
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Edit Job Redirection"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "File descr",IDC_STATIC,4,10,40,8
    EDITTEXT        IDC_FD,44,8,23,12,ES_NUMBER,0,HIDC_FD
    CONTROL         "Spin1",IDC_SCR_FD,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,66,8,7,14,0,HIDC_SCR_FD
    LTEXT           "(",IDC_STATIC,72,10,8,8
    EDITTEXT        IDC_STDFILE,80,8,40,12,ES_AUTOHSCROLL | ES_READONLY,0,
                    HIDC_STDFILE
    LTEXT           ")",IDC_STATIC,124,10,8,8
    LTEXT           "Connection",IDC_STATIC,4,32,36,8
    CONTROL         "File",IDC_CFILE,"Button",BS_AUTORADIOBUTTON | WS_GROUP | 
                    WS_TABSTOP,48,32,35,10,0,HIDC_CFILE
    CONTROL         "Pipe out to",IDC_PIPETO,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,48,48,44,10,0,HIDC_PIPETO
    CONTROL         "Pipe in from",IDC_PIPEFROM,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,48,64,48,10,0,HIDC_PIPEFROM
    CONTROL         "Close",IDC_CLOSEFILE,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,48,80,35,10,0,HIDC_CLOSEFILE
    CONTROL         "Dup f.d.",IDC_DUPFROM,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,48,96,35,10,0,HIDC_DUPFROM
    CONTROL         "Read",IDC_FREAD,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    104,32,35,10,0,HIDC_FREAD
    CONTROL         "Write",IDC_FWRITE,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    140,32,35,10,0,HIDC_FWRITE
    CONTROL         "Append",IDC_FAPPEND,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,176,32,35,10,0,HIDC_FAPPEND
    EDITTEXT        IDC_FILENAME,104,47,148,12,ES_AUTOHSCROLL,0,
                    HIDC_FILENAME
    EDITTEXT        IDC_FD2,104,96,23,12,ES_NUMBER,0,HIDC_FD2
    CONTROL         "Spin2",IDC_SCR_FD2,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,126,97,7,14,0,HIDC_SCR_FD2
    LTEXT           "(",IDC_BRAC,132,98,8,8
    EDITTEXT        IDC_STDFILE2,140,96,40,12,ES_AUTOHSCROLL | ES_READONLY,0,
                    HIDC_STDFILE2
    LTEXT           ")",IDC_KET,184,98,8,8
    DEFPUSHBUTTON   "OK",IDOK,4,120,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,202,120,50,14
END

IDD_JOBMODE DIALOGEX 0, 0, 232, 160
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job permissions / user / group"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "User",IDC_STATIC,84,8,16,8
    LTEXT           "Group",IDC_STATIC,112,8,20,8
    LTEXT           "Others",IDC_STATIC,136,8,24,8
    CONTROL         "Read",IDC_JUREAD,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,8,20,88,10,0,HIDC_JUREAD
    CONTROL         "Write",IDC_JUWRITE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,32,88,10,0,HIDC_JUWRITE
    CONTROL         "Reveal",IDC_JUREVEAL,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,44,88,10,0,HIDC_JUREVEAL
    CONTROL         "Display modes",IDC_JUDISPMODE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,56,88,10,0,HIDC_JUDISPMODE
    CONTROL         "Set modes",IDC_JUSETMODE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,68,88,10,0,HIDC_JUSETMODE
    CONTROL         "Assume ownership",IDC_JUASSOWN,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,80,88,10,0,HIDC_JUASSOWN
    CONTROL         "Assume group ownership",IDC_JUASSGOWN,"Button",
                    BS_AUTOCHECKBOX | BS_LEFTTEXT | WS_TABSTOP,8,92,88,10,0,
                    HIDC_JUASSGOWN
    CONTROL         "Give away ownership",IDC_JUGOWN,"Button",
                    BS_AUTOCHECKBOX | BS_LEFTTEXT | WS_TABSTOP,8,104,88,10,0,
                    HIDC_JUGOWN
    CONTROL         "Give away group",IDC_JUGGROUP,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,116,88,10,0,HIDC_JUGGROUP
    CONTROL         "Delete",IDC_JUDELETE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,128,88,10,0,HIDC_JUDELETE
    CONTROL         "Kill",IDC_JUKILL,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,8,140,88,10,0,HIDC_JUKILL
    CONTROL         "",IDC_JGREAD,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,20,12,10,0,HIDC_JGREAD
    CONTROL         "",IDC_JGWRITE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,32,12,10,0,HIDC_JGWRITE
    CONTROL         "",IDC_JGREVEAL,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,44,12,10,0,HIDC_JGREVEAL
    CONTROL         "",IDC_JGDISPMODE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,56,12,10,0,HIDC_JGDISPMODE
    CONTROL         "",IDC_JGSETMODE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,68,12,10,0,HIDC_JGSETMODE
    CONTROL         "",IDC_JGASSOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,80,12,10,0,HIDC_JGASSOWN
    CONTROL         "",IDC_JGASSGOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,92,12,10,0,HIDC_JGASSGOWN
    CONTROL         "",IDC_JGGOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,104,12,10,0,HIDC_JGGOWN
    CONTROL         "",IDC_JGGGROUP,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,116,12,10,0,HIDC_JGGGROUP
    CONTROL         "",IDC_JGDELETE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,128,12,10,0,HIDC_JGDELETE
    CONTROL         "",IDC_JGKILL,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,140,12,10,0,HIDC_JGKILL
    CONTROL         "",IDC_JOREAD,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,20,12,10,0,HIDC_JOREAD
    CONTROL         "",IDC_JOWRITE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,32,12,10,0,HIDC_JOWRITE
    CONTROL         "",IDC_JOREVEAL,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,44,12,10,0,HIDC_JOREVEAL
    CONTROL         "",IDC_JODISPMODE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,56,12,10,0,HIDC_JODISPMODE
    CONTROL         "",IDC_JOSETMODE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,68,12,10,0,HIDC_JOSETMODE
    CONTROL         "",IDC_JOASSOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,80,12,10,0,HIDC_JOASSOWN
    CONTROL         "",IDC_JOASSGOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,92,12,10,0,HIDC_JOASSGOWN
    CONTROL         "",IDC_JOGOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,104,12,10,0,HIDC_JOGOWN
    CONTROL         "",IDC_JOGGROUP,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,116,12,10,0,HIDC_JOGGROUP
    CONTROL         "",IDC_JODELETE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,128,12,10,0,HIDC_JODELETE
    CONTROL         "",IDC_JOKILL,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,140,12,10,0,HIDC_JOKILL
    COMBOBOX        IDC_USER,168,16,61,56,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_USER
    COMBOBOX        IDC_GROUP,168,44,61,56,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_GROUP
    DEFPUSHBUTTON   "OK",IDOK,190,110,39,14
    PUSHBUTTON      "Cancel",IDCANCEL,190,138,39,14
END

IDD_VARMODE DIALOGEX 0, 0, 268, 143
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Variable permissions / user /group"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "User",IDC_STATIC,84,8,16,8
    LTEXT           "Group",IDC_STATIC,112,8,24,8
    LTEXT           "Others",IDC_STATIC,140,8,20,8
    CONTROL         "Read",IDC_VUREAD,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,8,20,88,10,0,HIDC_VUREAD
    CONTROL         "Write",IDC_VUWRITE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,32,88,10,0,HIDC_VUWRITE
    CONTROL         "Reveal",IDC_VUREVEAL,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,44,88,10,0,HIDC_VUREVEAL
    CONTROL         "Display modes",IDC_VUDISPMODE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,56,88,10,0,HIDC_VUDISPMODE
    CONTROL         "Set modes",IDC_VUSETMODE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,68,88,10,0,HIDC_VUSETMODE
    CONTROL         "Assume ownership",IDC_VUASSOWN,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,80,88,10,0,HIDC_VUASSOWN
    CONTROL         "Assume group ownership",IDC_VUASSGOWN,"Button",
                    BS_AUTOCHECKBOX | BS_LEFTTEXT | WS_TABSTOP,8,92,88,10,0,
                    HIDC_VUASSGOWN
    CONTROL         "Give away ownership",IDC_VUGOWN,"Button",
                    BS_AUTOCHECKBOX | BS_LEFTTEXT | WS_TABSTOP,8,104,88,10,0,
                    HIDC_VUGOWN
    CONTROL         "Give away group",IDC_VUGGROUP,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,116,88,10,0,HIDC_VUGGROUP
    CONTROL         "Delete",IDC_VUDELETE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,8,128,88,10,0,HIDC_VUDELETE
    CONTROL         "",IDC_VGREAD,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,20,12,10,0,HIDC_VGREAD
    CONTROL         "",IDC_VGWRITE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,32,12,10,0,HIDC_VGWRITE
    CONTROL         "",IDC_VGREVEAL,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,44,12,10,0,HIDC_VGREVEAL
    CONTROL         "",IDC_VGDISPMODE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,56,12,10,0,HIDC_VGDISPMODE
    CONTROL         "",IDC_VGSETMODE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,68,12,10,0,HIDC_VGSETMODE
    CONTROL         "",IDC_VGASSOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,80,12,10,0,HIDC_VGASSOWN
    CONTROL         "",IDC_VGASSGOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,92,12,10,0,HIDC_VGASSGOWN
    CONTROL         "",IDC_VGGOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,104,12,10,0,HIDC_VGGOWN
    CONTROL         "",IDC_VGGGROUP,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,116,12,10,0,HIDC_VGGGROUP
    CONTROL         "",IDC_VGDELETE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,112,128,12,10,0,HIDC_VGDELETE
    CONTROL         "",IDC_VOREAD,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,20,12,10,0,HIDC_VOREAD
    CONTROL         "",IDC_VOWRITE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,32,12,10,0,HIDC_VOWRITE
    CONTROL         "",IDC_VOREVEAL,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,44,12,10,0,HIDC_VOREVEAL
    CONTROL         "",IDC_VODISPMODE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,56,12,10,0,HIDC_VODISPMODE
    CONTROL         "",IDC_VOSETMODE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,68,12,10,0,HIDC_VOSETMODE
    CONTROL         "",IDC_VOASSOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,80,12,10,0,HIDC_VOASSOWN
    CONTROL         "",IDC_VOASSGOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,92,12,10,0,HIDC_VOASSGOWN
    CONTROL         "",IDC_VOGOWN,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,104,12,10,0,HIDC_VOGOWN
    CONTROL         "",IDC_VOGGROUP,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,116,12,10,0,HIDC_VOGGROUP
    CONTROL         "",IDC_VODELETE,"Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | 
                    WS_TABSTOP,140,128,12,10,0,HIDC_VODELETE
    COMBOBOX        IDC_USER,168,16,77,60,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_USER
    COMBOBOX        IDC_GROUP,168,52,77,60,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_GROUP
    DEFPUSHBUTTON   "OK",IDOK,200,84,39,14
    PUSHBUTTON      "Cancel",IDCANCEL,200,120,39,14
END

IDD_OTHERSIG DIALOGEX 0, 0, 124, 91
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Send kill signal"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    CONTROL         "Hangup",IDC_SIG_HANGUP,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,8,8,35,10,0,HIDC_SIG_HANGUP
    CONTROL         "Interrupt",IDC_SIG_INTERRUPT,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,8,25,35,10,0,
                    HIDC_SIG_INTERRUPT
    CONTROL         "Quit",IDC_SIG_QUIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,8,42,35,10,0,HIDC_SIG_QUIT
    CONTROL         "Terminate",IDC_SIG_TERMINATE,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,8,59,40,10,0,
                    HIDC_SIG_TERMINATE
    CONTROL         "KILL",IDC_SIG_KILL,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,8,76,35,10,0,HIDC_SIG_KILL
    PUSHBUTTON      "OK",IDOK,68,8,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,68,40,50,14
END

IDD_WINOPTS DIALOGEX 0, 0, 223, 151
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Window Options"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Restrict display to: Job queue",IDC_JOBQNAME,4,13,96,10
    COMBOBOX        IDC_JOBQUEUE,104,12,52,64,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_JOBQUEUE
    CONTROL         "Including empty",IDC_INCNULL,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,164,13,56,10,0,HIDC_INCNULL
    LTEXT           "User",IDC_STATIC,12,38,20,8
    COMBOBOX        IDC_USER,35,36,48,56,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_USER
    LTEXT           "Group",IDC_STATIC,104,38,20,8
    COMBOBOX        IDC_GROUP,132,36,48,60,CBS_DROPDOWN | CBS_AUTOHSCROLL | 
                    CBS_SORT | WS_VSCROLL | WS_TABSTOP,0,HIDC_GROUP
    GROUPBOX        "Confirm delete jobs",IDC_DELJOBSNAME,8,56,75,49
    CONTROL         "Never",IDC_NEVER,"Button",BS_AUTORADIOBUTTON | WS_GROUP | 
                    WS_TABSTOP,13,71,45,12,0,HIDC_NEVER
    CONTROL         "Always",IDC_ALWAYS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,13,86,34,12,0,HIDC_ALWAYS
    GROUPBOX        "Host display",IDC_STATIC,104,56,96,49
    CONTROL         "Display local host only",IDC_LOCALONLY,"Button",
                    BS_AUTORADIOBUTTON | WS_GROUP | WS_TABSTOP,109,71,83,12,
                    0,HIDC_LOCALONLY
    CONTROL         "Display all hosts",IDC_DISPALL,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,109,86,63,12,0,
                    HIDC_DISPALL
    DEFPUSHBUTTON   "OK",IDOK,17,124,33,17
    PUSHBUTTON      "Cancel",IDCANCEL,175,124,33,17
END

IDD_VSEARCH DIALOGEX 0, 0, 228, 119
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Search for variable"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Search",IDC_STATIC,13,18,39,9
    EDITTEXT        IDC_LOOKFOR,62,15,162,15,ES_AUTOHSCROLL,0,HIDC_LOOKFOR
    CONTROL         "Forward",IDC_SEARCH_FORWARD,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP,19,49,83,12,0,HIDC_SEARCH_FORWARD
    CONTROL         "Backward",IDC_SEARCH_BACK,"Button",BS_AUTORADIOBUTTON,
                    19,68,65,10,0,HIDC_SEARCH_BACK
    CONTROL         "Wrap Around",IDC_WRAPROUND,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,19,86,83,12,0,HIDC_WRAPROUND
    CONTROL         "User",IDC_SRCH_USER,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,109,49,44,12,0,HIDC_SRCH_USER
    CONTROL         "Variable name",IDC_SRCH_VNAME,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,109,67,65,11,0,HIDC_SRCH_VNAME
    CONTROL         "Value",IDC_VVALUE,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    109,84,52,10,0,HIDC_VVALUE
    CONTROL         "Comment",IDC_VCOMMENT,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,109,100,44,10,0,HIDC_VCOMMENT
    DEFPUSHBUTTON   "OK",IDOK,184,44,36,17
    PUSHBUTTON      "Cancel",IDCANCEL,184,80,36,17
END

IDD_VARASS DIALOGEX 0, 0, 176, 119
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Assign Variable"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    EDITTEXT        IDC_DVARNAME,8,12,84,13,ES_AUTOHSCROLL | ES_READONLY | 
                    NOT WS_BORDER | NOT WS_TABSTOP
    EDITTEXT        IDC_DVARCOMMENT,8,40,164,13,ES_AUTOHSCROLL | ES_READONLY | 
                    NOT WS_BORDER | NOT WS_TABSTOP
    EDITTEXT        IDC_AVARVALUE,8,68,148,12,ES_AUTOHSCROLL,0,
                    HIDC_AVARVALUE
    CONTROL         "Spin1",IDC_SCR_AVARVALUE,"msctls_updown32",
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS,159,67,10,
                    14,0,HIDC_SCR_AVARVALUE
    DEFPUSHBUTTON   "OK",IDOK,8,96,40,14
    PUSHBUTTON      "Cancel",IDCANCEL,130,96,40,14
END

IDD_VARCOMM DIALOGEX 0, 0, 228, 115
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Variable Comment"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    EDITTEXT        IDC_DVARNAME,10,15,108,16,ES_AUTOHSCROLL | ES_READONLY | 
                    NOT WS_BORDER | NOT WS_TABSTOP
    EDITTEXT        IDC_AVARCOMMENT,10,49,211,12,ES_AUTOHSCROLL,0,
                    HIDC_AVARCOMMENT
    DEFPUSHBUTTON   "OK",IDOK,8,84,51,17
    PUSHBUTTON      "Cancel",IDCANCEL,170,84,51,17
END

IDD_CONSTVAL DIALOGEX 0, 0, 148, 59
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Constant for Arithmetic ops"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    EDITTEXT        IDC_CONSTVALUE,24,12,73,12,ES_AUTOHSCROLL | ES_NUMBER,0,
                    HIDC_CONSTVALUE
    CONTROL         "Spin1",IDC_SCR_CONSTVALUE,"msctls_updown32",
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS,99,11,10,
                    14,0,HIDC_SCR_CONSTVALUE
    DEFPUSHBUTTON   "OK",IDOK,4,32,48,17
    PUSHBUTTON      "Cancel",IDCANCEL,95,32,48,17
END

IDD_JOBFILE DIALOG DISCARDABLE  0, 0, 76, 15
STYLE DS_MODALFRAME | WS_POPUP | WS_VISIBLE | WS_CAPTION | WS_SYSMENU
CAPTION "Dialog"
FONT 8, "MS Sans Serif"
BEGIN
END

IDD_BATFILE DIALOG DISCARDABLE  0, 0, 80, 47
STYLE DS_MODALFRAME | WS_POPUP | WS_VISIBLE | WS_CAPTION | WS_SYSMENU
CAPTION "Dialog"
FONT 8, "MS Sans Serif"
BEGIN
END

IDD_FORMATDEF DIALOGEX 0, 0, 319, 179
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Set up formats"
FONT 8, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "For:",IDC_STATIC,24,14,16,8
    EDITTEXT        IDC_WHAT4,80,12,127,13,ES_AUTOHSCROLL | NOT WS_BORDER | 
                    NOT WS_TABSTOP
    LISTBOX         IDC_FMTLIST,4,40,220,99,LBS_USETABSTOPS | 
                    LBS_NOINTEGRALHEIGHT | WS_VSCROLL | WS_HSCROLL | 
                    WS_TABSTOP,0,HIDC_FMTLIST
    PUSHBUTTON      "New",IDC_NEWFMT,233,40,37,14,0,0,HIDC_NEWFMT
    PUSHBUTTON      "New sep",IDC_NEWSEP,276,40,37,14,0,0,HIDC_NEWSEP
    PUSHBUTTON      "Edit",IDC_EDITFMT,233,82,37,14,0,0,HIDC_EDITFMT
    PUSHBUTTON      "Delete",IDC_DELFMT,276,82,37,14,0,0,HIDC_DELFMT
    PUSHBUTTON      "Reset Default format",IDC_RESETDEFLT,231,124,80,14,0,0,
                    HIDC_RESETDEFLT
    DEFPUSHBUTTON   "OK",IDOK,4,155,37,14
    PUSHBUTTON      "Cancel",IDCANCEL,274,155,37,14
END

IDD_EDITSEP DIALOGEX 0, 0, 272, 59
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "New separator string"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "String:",IDC_STATIC,8,12,40,12
    EDITTEXT        IDC_SEPVALUE,48,8,168,15,ES_AUTOHSCROLL,0,HIDC_SEPVALUE
    DEFPUSHBUTTON   "OK",IDOK,8,36,42,18
    PUSHBUTTON      "Cancel",IDCANCEL,220,36,42,18
END

IDD_COPYJOPTS DIALOGEX 0, 0, 186, 92
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Copy job options"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    GROUPBOX        "Set queuing options",IDC_STATIC,12,0,132,48
    CONTROL         "As cancelled",IDC_ASCANC,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,16,12,108,8,0,HIDC_ASCANC
    CONTROL         "As ready to run",IDC_ASREADY,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,16,30,108,8,0,
                    HIDC_ASREADY
    DEFPUSHBUTTON   "OK",IDOK,12,65,39,22
    PUSHBUTTON      "Cancel",IDCANCEL,140,65,39,22
END

IDD_USERPERM DIALOGEX 0, 0, 184, 163
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "User Permissions"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "User:",IDC_STATIC,12,8,30,8
    EDITTEXT        IDC_USER,56,5,60,13,ES_AUTOHSCROLL | ES_READONLY,0,
                    HIDC_USER
    LTEXT           "Group:",IDC_STATIC,12,31,30,8
    EDITTEXT        IDC_GROUP,56,28,60,13,ES_AUTOHSCROLL | ES_READONLY,0,
                    HIDC_GROUP
    CONTROL         "Read admin",IDC_RADMIN,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,44,68,10,0,HIDC_RADMIN
    CONTROL         "Write admin",IDC_WADMIN,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,56,68,10,0,HIDC_WADMIN
    CONTROL         "Create entry",IDC_CREATE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,68,68,10,0,HIDC_CREATE
    CONTROL         "Special Create",IDC_SPCREATE,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,80,68,10,0,HIDC_SPCREATE
    CONTROL         "Stop Scheduler",IDC_SSTOP,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,92,68,10,0,HIDC_SSTOP
    CONTROL         "Override def perms",IDC_UMASK,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,104,68,10,0,HIDC_UMASK
    CONTROL         "OR user/group",IDC_ORUG,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,116,68,10,0,HIDC_ORUG
    CONTROL         "OR user/other",IDC_ORUO,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,128,68,10,0,HIDC_ORUO
    CONTROL         "OR group/other",IDC_ORGO,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,12,140,68,10,0,HIDC_ORGO
    LTEXT           "Max LL",IDC_STATIC,89,50,30,8
    EDITTEXT        IDC_MAXLL,131,48,40,13,ES_AUTOHSCROLL | ES_READONLY,0,
                    HIDC_MAXLL
    LTEXT           "Tot LL",IDC_STATIC,89,70,20,8
    EDITTEXT        IDC_TOTLL,131,68,40,13,ES_AUTOHSCROLL | ES_READONLY,0,
                    HIDC_TOTLL
    LTEXT           "Spec LL",IDC_STATIC,89,90,30,8
    EDITTEXT        IDC_SPECLL,131,88,40,13,ES_AUTOHSCROLL | ES_READONLY,0,
                    HIDC_SPECLL
    DEFPUSHBUTTON   "OK",IDOK,125,110,46,17
    PUSHBUTTON      "Cancel",IDCANCEL,125,136,46,17
END

IDD_NETSTATS DIALOGEX 0, 0, 240, 111
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Network Status"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Host",IDC_STATIC,24,20,30,8
    COMBOBOX        IDC_HOST,72,18,76,76,CBS_DROPDOWNLIST | CBS_SORT | 
                    WS_VSCROLL | WS_TABSTOP,0,HIDC_HOST
    CONTROL         "Probe sent (or no probe required)",IDC_NS_PROBESENT,
                    "Button",BS_AUTOCHECKBOX | BS_LEFTTEXT | WS_TABSTOP,24,
                    40,124,10,0,HIDC_NS_PROBESENT
    CONTROL         "TCP Connection made",IDC_CONNECTED,"Button",
                    BS_AUTOCHECKBOX | BS_LEFTTEXT | WS_TABSTOP,24,58,124,10,
                    0,HIDC_CONNECTED
    CONTROL         "Sync Requested",IDC_NS_SYNCREQ,"Button",BS_AUTOCHECKBOX | 
                    BS_LEFTTEXT | WS_TABSTOP,24,76,124,10,0,HIDC_NS_SYNCREQ
    CONTROL         "Sync Completed",IDC_NS_SYNCDONE,"Button",
                    BS_AUTOCHECKBOX | BS_LEFTTEXT | WS_TABSTOP,24,94,124,10,
                    0,HIDC_NS_SYNCDONE
    DEFPUSHBUTTON   "OK",IDOK,176,16,46,17
    PUSHBUTTON      "Cancel",IDCANCEL,176,50,46,17
END

IDD_DEFASS DIALOGEX 0, 0, 252, 199
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Assignment defaults"
FONT 8, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Value",IDC_STATIC,17,9,39,10
    EDITTEXT        IDC_VALUE,68,8,148,12,ES_AUTOHSCROLL,0,HIDC_VALUE
    CONTROL         "Spin1",IDC_SCR_VALUE,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,221,7,9,14,0,
                    HIDC_SCR_VALUE
    GROUPBOX        "Assignment type",IDC_STATIC,4,40,129,86
    CONTROL         "Set",IDC_ASET,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_GROUP | WS_TABSTOP,24,58,25,15,0,HIDC_ASET
    CONTROL         "+",IDC_AADD,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,24,81,25,15,0,HIDC_AADD
    CONTROL         "-",IDC_ASUB,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,24,106,25,15,0,HIDC_ASUB
    CONTROL         "X",IDC_AMULT,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,57,58,25,15,0,HIDC_AMULT
    CONTROL         "/",IDC_ADIV,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,57,81,25,15,0,HIDC_ADIV
    CONTROL         "Md",IDC_AMOD,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,57,106,25,15,0,HIDC_AMOD
    CONTROL         "Exit",IDC_AEXIT,"Button",BS_AUTORADIOBUTTON | 
                    BS_LEFTTEXT | WS_TABSTOP,87,58,35,15,0,HIDC_AEXIT
    CONTROL         "Sig",IDC_ASIGNAL,"Button",BS_AUTORADIOBUTTON | 
                    BS_LEFTTEXT | WS_TABSTOP,87,81,35,15,0,HIDC_ASIGNAL
    GROUPBOX        "If host unavailable",IDC_STATIC,4,133,126,60
    CONTROL         "Ignore",IDC_ANOTCRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,11,152,58,15,0,HIDC_ANOTCRIT
    CONTROL         "Hold job",IDC_ACRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,11,170,99,15,0,HIDC_ACRIT
    CONTROL         "On start",IDC_ASTART,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,161,40,46,11,0,HIDC_ASTART
    CONTROL         "REVERSE on exit",IDC_AREVERSE,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,161,56,85,12,0,HIDC_AREVERSE
    CONTROL         "Normal exit",IDC_ANORMAL,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,161,73,61,10,0,HIDC_ANORMAL
    CONTROL         "Error exit",IDC_AERROR,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,161,88,61,12,0,HIDC_AERROR
    CONTROL         "Abort",IDC_AABORT,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    161,105,61,12,0,HIDC_AABORT
    CONTROL         "Cancel",IDC_ACANCEL,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,161,122,61,12,0,HIDC_ACANCEL
    DEFPUSHBUTTON   "OK",IDOK,190,150,44,17
    PUSHBUTTON      "Cancel",IDCANCEL,190,176,44,17
END

IDD_DEFCONDOPT DIALOGEX 0, 0, 236, 115
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Condition defaults"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    EDITTEXT        IDC_VALUE,12,12,113,13,ES_AUTOHSCROLL,0,HIDC_VALUE
    CONTROL         "Spin1",IDC_SCR_VALUE,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,130,11,7,14,0,
                    HIDC_SCR_VALUE
    LTEXT           "Value",IDC_STATIC,151,13,40,10
    GROUPBOX        "Comparison",IDC_STATIC,12,40,73,70
    CONTROL         "=",IDC_CEQ,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_GROUP | WS_TABSTOP,28,55,19,12,0,HIDC_CEQ
    CONTROL         "!=",IDC_CNE,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,28,74,19,12,0,HIDC_CNE
    CONTROL         "<",IDC_CLT,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,28,94,19,12,0,HIDC_CLT
    CONTROL         "<=",IDC_CLE,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,53,55,19,12,0,HIDC_CLE
    CONTROL         ">",IDC_CGT,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,53,74,19,12,0,HIDC_CGT
    CONTROL         ">=",IDC_CGE,"Button",BS_AUTORADIOBUTTON | BS_LEFTTEXT | 
                    WS_TABSTOP,53,94,19,12,0,HIDC_CGE
    GROUPBOX        "If host unavailable",IDC_STATIC,92,44,98,49
    CONTROL         "Ignore",IDC_CNOTCRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,97,58,45,12,0,HIDC_CNOTCRIT
    CONTROL         "Hold job",IDC_CCRIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,97,73,77,12,0,HIDC_CCRIT
    DEFPUSHBUTTON   "OK",IDOK,196,16,36,17
    PUSHBUTTON      "Cancel",IDCANCEL,196,40,36,17
END

IDD_DEFTIMOPT DIALOGEX 0, 0, 271, 210
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Time defaults"
FONT 8, "MS Sans Serif", 0, 0, 0x1
BEGIN
    CONTROL         "Run and delete",IDC_DELETE,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,76,0,76,10,0,HIDC_DELETE
    CONTROL         "Run and retain",IDC_RETAIN,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,76,13,84,10,0,HIDC_RETAIN
    CONTROL         "Minutes",IDC_REPMINS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,76,32,40,10,0,HIDC_REPMINS
    CONTROL         "Hours",IDC_REPHOURS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,76,45,34,10,0,HIDC_REPHOURS
    CONTROL         "Days",IDC_REPDAYS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,76,56,34,10,0,HIDC_REPDAYS
    CONTROL         "Weeks",IDC_REPWEEKS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,76,69,34,10,0,HIDC_REPWEEKS
    CONTROL         "Months (rel begin)",IDC_REPMONTHSB,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,76,80,72,10,0,
                    HIDC_REPMONTHSB
    CONTROL         "Months (rel end)",IDC_REPMONTHSE,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,76,93,76,10,0,
                    HIDC_REPMONTHSE
    CONTROL         "Years",IDC_REPYEARS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,76,104,34,10,0,HIDC_REPYEARS
    GROUPBOX        "Repeat every",IDC_MESS_REPEATEVERY,8,21,156,100
    EDITTEXT        IDC_REPEAT,20,40,34,12,ES_AUTOHSCROLL,0,HIDC_REPEAT
    CONTROL         "Spin1",IDC_SCR_REPEAT,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,57,39,10,14,0,HIDC_SCR_REPEAT
    LTEXT           "Month day",IDC_MONDAYNAME,20,69,44,8
    EDITTEXT        IDC_MONTHDAY,20,85,34,12,ES_AUTOHSCROLL | ES_READONLY | 
                    ES_NUMBER,0,HIDC_MONTHDAY
    CONTROL         "Spin2",IDC_SCR_MONTHDAY,"msctls_updown32",
                    UDS_SETBUDDYINT | UDS_ALIGNRIGHT | UDS_AUTOBUDDY | 
                    UDS_ARROWKEYS | UDS_NOTHOUSANDS,57,84,10,14,0,
                    HIDC_SCR_MONTHDAY
    GROUPBOX        "Avoiding...",IDC_MESS_AVOIDING,168,21,96,60
    CONTROL         "Sun",IDC_AVSUN,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    172,32,34,10,0,HIDC_AVSUN
    CONTROL         "Mon",IDC_AVMON,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    172,45,34,8,0,HIDC_AVMON
    CONTROL         "Tue",IDC_AVTUE,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    172,56,34,10,0,HIDC_AVTUE
    CONTROL         "Wed",IDC_AVWED,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    172,69,34,10,0,HIDC_AVWED
    CONTROL         "Thur",IDC_AVTHU,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    216,32,34,10,0,HIDC_AVTHU
    CONTROL         "Fri",IDC_AVFRI,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    216,45,34,10,0,HIDC_AVFRI
    CONTROL         "Sat",IDC_AVSAT,"Button",BS_AUTOCHECKBOX | WS_TABSTOP,
                    216,56,34,10,0,HIDC_AVSAT
    CONTROL         "Holiday",IDC_AVHOLIDAY,"Button",BS_AUTOCHECKBOX | 
                    WS_TABSTOP,216,69,42,10,0,HIDC_AVHOLIDAY
    GROUPBOX        "If not possible",IDC_MESS_NOTPOSS,80,128,83,76
    CONTROL         "Skip",IDC_NPSKIP,"Button",BS_AUTORADIOBUTTON | WS_GROUP | 
                    WS_TABSTOP,84,144,34,10,0,HIDC_NPSKIP
    CONTROL         "Delay Current",IDC_NPDELCURR,"Button",
                    BS_AUTORADIOBUTTON | WS_TABSTOP,84,160,72,10,0,
                    HIDC_NPDELCURR
    CONTROL         "Delay all",IDC_NPDELALL,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,84,176,57,10,0,HIDC_NPDELALL
    CONTROL         "Catch up",IDC_NPCATCHUP,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,84,192,57,10,0,HIDC_NPCATCHUP
    DEFPUSHBUTTON   "OK",IDOK,210,150,40,14
    PUSHBUTTON      "Cancel",IDCANCEL,210,174,40,14
END

IDD_TIMELIMS DIALOGEX 0, 0, 212, 135
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Job time limits"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Delete job after (hours)",IDC_STATIC,8,12,76,7
    EDITTEXT        IDC_DELTIME,96,9,50,12,ES_READONLY,0,HIDC_DELTIME
    CONTROL         "Spin1",IDC_SCR_DELTIME,"msctls_updown32",
                    UDS_SETBUDDYINT | UDS_ALIGNRIGHT | UDS_AUTOBUDDY | 
                    UDS_ARROWKEYS | UDS_NOTHOUSANDS,147,7,10,14,0,
                    HIDC_SCR_DELTIME
    LTEXT           "Maximum run time",IDC_STATIC,8,32,72,8
    EDITTEXT        IDC_HOUR,96,30,21,12,ES_READONLY | ES_NUMBER,0,HIDC_HOUR
    CONTROL         "Spin2",IDC_SCR_HOUR,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,108,29,10,14,0,
                    HIDC_SCR_HOUR
    LTEXT           ":",IDC_COLON,118,33,2,7
    EDITTEXT        IDC_MIN,121,30,21,12,ES_READONLY | ES_NUMBER,0,HIDC_MIN
    CONTROL         "Spin3",IDC_SCR_MIN,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,133,29,10,14,0,
                    HIDC_SCR_MIN
    LTEXT           ":",IDC_COLON2,144,32,2,7
    EDITTEXT        IDC_SEC,148,30,21,12,ES_READONLY | ES_NUMBER,0,HIDC_SEC
    CONTROL         "Spin4",IDC_SCR_SEC,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,162,29,10,14,0,
                    HIDC_SCR_SEC
    PUSHBUTTON      "OFF",IDC_RTOFF,176,29,28,14,0,0,HIDC_RTOFF
    GROUPBOX        "Kill With",IDC_STATIC,28,48,133,53
    CONTROL         "Sigterm",IDC_KW_TERM,"Button",BS_AUTORADIOBUTTON | 
                    WS_GROUP | WS_TABSTOP,33,61,35,10,0,HIDC_KW_TERM
    CONTROL         "Sigkill",IDC_KW_KILL,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,33,73,35,10,0,HIDC_KW_KILL
    CONTROL         "Sighup",IDC_KW_HUP,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,33,85,35,10,0,HIDC_KW_HUP
    CONTROL         "Sigint",IDC_KW_INT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,77,61,35,10,0,HIDC_KW_INT
    CONTROL         "Sigquit",IDC_KW_QUIT,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,77,73,35,10,0,HIDC_KW_QUIT
    CONTROL         "Sigalrm",IDC_KW_ARLM,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,77,85,35,10,0,HIDC_KW_ARLM
    CONTROL         "Sigbus",IDC_KW_BUS,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,121,61,35,10,0,HIDC_KW_BUS
    CONTROL         "Sigsegv",IDC_KW_SEGV,"Button",BS_AUTORADIOBUTTON | 
                    WS_TABSTOP,121,73,35,10,0,HIDC_KW_SEGV
    LTEXT           "Allow to clean up for",IDC_STATIC,8,111,68,8
    EDITTEXT        IDC_MIN2,78,109,23,12,ES_READONLY,0,HIDC_MIN2
    CONTROL         "Spin5",IDC_SCR_MIN2,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,104,108,10,14,0,
                    HIDC_SCR_MIN2
    LTEXT           ":",IDC_COLON3,109,110,2,7
    EDITTEXT        IDC_SEC2,115,109,23,12,ES_READONLY,0,HIDC_SEC2
    CONTROL         "Spin6",IDC_SCR_SEC2,"msctls_updown32",UDS_ALIGNRIGHT | 
                    UDS_AUTOBUDDY | UDS_ARROWKEYS,140,105,7,14,0,
                    HIDC_SCR_SEC2
    DEFPUSHBUTTON   "OK",IDOK,168,68,36,14,0,0,HIDOK
    PUSHBUTTON      "Cancel",IDCANCEL,168,107,36,14
END

IDD_EDITFMT DIALOGEX 0, 0, 243, 131
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_VISIBLE | WS_CAPTION | 
    WS_SYSMENU
CAPTION "Edit Format Code"
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Format code",IDC_STATIC,16,30,48,7
    COMBOBOX        IDC_FMTCODE,88,28,140,84,CBS_DROPDOWNLIST | 
                    CBS_AUTOHSCROLL | WS_VSCROLL | WS_TABSTOP,0,HIDC_FMTCODE
    LTEXT           "Width",IDC_STATIC,16,66,30,8
    EDITTEXT        IDC_WIDTH,88,64,28,12,ES_AUTOHSCROLL | ES_NUMBER,0,
                    HIDC_WIDTH
    CONTROL         "Spin1",IDC_SCR_WIDTH,"msctls_updown32",UDS_SETBUDDYINT | 
                    UDS_ALIGNRIGHT | UDS_AUTOBUDDY | UDS_ARROWKEYS | 
                    UDS_NOTHOUSANDS,117,63,10,14,0,HIDC_SCR_WIDTH
    CONTROL         "Tab format left if too long",IDC_TABLEFT,"Button",
                    BS_AUTOCHECKBOX | WS_TABSTOP,136,64,84,10,0,HIDC_TABLEFT
    CONTROL         "Skip fields to right if too long",IDC_SKIPRIGHT,"Button",
                    BS_AUTOCHECKBOX | WS_TABSTOP,136,80,96,10,0,
                    HIDC_SKIPRIGHT
    DEFPUSHBUTTON   "OK",IDOK,8,100,42,18
    PUSHBUTTON      "Cancel",IDCANCEL,186,100,42,18
END

IDD_LOGINHOST DIALOGEX 0, 0, 186, 131
STYLE DS_MODALFRAME | DS_CONTEXTHELP | WS_POPUP | WS_CAPTION | WS_SYSMENU
CAPTION "Please log in to Unix Host...."
FONT 10, "MS Sans Serif", 0, 0, 0x1
BEGIN
    LTEXT           "Login to Unix Host",IDC_STATIC,13,15,55,8
    EDITTEXT        IDC_UNIXHOST,90,13,67,12,ES_AUTOHSCROLL | ES_READONLY | 
                    NOT WS_BORDER | NOT WS_TABSTOP
    LTEXT           "Client Host Name",IDC_STATIC,13,37,53,8
    EDITTEXT        IDC_CLIENTHOST,90,35,67,12,ES_AUTOHSCROLL | ES_READONLY | 
                    NOT WS_BORDER | NOT WS_TABSTOP
    LTEXT           "User Name",IDC_STATIC,13,59,35,8
    EDITTEXT        IDC_USERNAME,64,56,94,14,ES_AUTOHSCROLL,0,HIDC_USERNAME
    LTEXT           "Password",IDC_STATIC,13,81,31,8
    EDITTEXT        IDC_PASSWD,64,78,94,14,ES_PASSWORD | ES_AUTOHSCROLL,0,
                    HIDC_PASSWD
    DEFPUSHBUTTON   "OK",IDOK,7,110,50,14
    PUSHBUTTON      "Cancel",IDCANCEL,129,110,50,14
END


/////////////////////////////////////////////////////////////////////////////
//
// Bitmap
//

IDR_MAINFRAME           BITMAP  DISCARDABLE     "RES\\IDR_MAIN.BMP"

/////////////////////////////////////////////////////////////////////////////
//
// Toolbar
//

IDR_MAINFRAME TOOLBAR DISCARDABLE  16, 15
BEGIN
    BUTTON      ID_FILE_PROGRAMOPTIONS
    BUTTON      ID_FILE_SAVEFILE
    BUTTON      ID_WINDOW_WINDOWOPTIONS
    SEPARATOR
    BUTTON      ID_JOBS_VIEWJOB
    BUTTON      ID_ACTION_TITLEPRILOADLEV
    BUTTON      ID_ACTION_DELETEJOB
    BUTTON      ID_ACTION_SETRUNNABLE
    BUTTON      ID_ACTION_SETCANCELLED
    SEPARATOR
    BUTTON      ID_ACTION_FORCERUN
    BUTTON      ID_ACTION_GOJOB
    BUTTON      ID_JOBS_ADVANCETIME
    SEPARATOR
    BUTTON      ID_ACTION_KILLJOB
    BUTTON      ID_ACTION_QUITJOB
    SEPARATOR
    BUTTON      ID_JOBS_TIME
    BUTTON      ID_CONDITIONS_JOBCONDITIONS
    BUTTON      ID_CONDITIONS_JOBASSIGNMENTS
    SEPARATOR
    BUTTON      ID_VARIABLES_ASSIGN
    BUTTON      ID_VARIABLES_INCREMENT
    BUTTON      ID_VARIABLES_DECREMENT
    SEPARATOR
    BUTTON      ID_APP_ABOUT
    BUTTON      ID_CONTEXT_HELP
END


/////////////////////////////////////////////////////////////////////////////
//
// DESIGNINFO
//

#ifdef APSTUDIO_INVOKED
GUIDELINES DESIGNINFO DISCARDABLE 
BEGIN
    IDD_LOGINHOST, DIALOG
    BEGIN
        LEFTMARGIN, 7
        RIGHTMARGIN, 179
        TOPMARGIN, 7
        BOTTOMMARGIN, 124
    END
END
#endif    // APSTUDIO_INVOKED


/////////////////////////////////////////////////////////////////////////////
//
// String Table
//

STRINGTABLE PRELOAD DISCARDABLE 
BEGIN
    IDR_MAINFRAME           "BTQW- Xi-Batch Windows Queue Management"
END

STRINGTABLE PRELOAD DISCARDABLE 
BEGIN
    IDP_TOO_MANY_ROWS       "Sorry - too many rows to accomodate in job/printer display."
    IDP_NOJOBSELECTED       "You must select a job first.  (Click on one)"
    IDP_NOVARSELECTED       "You must select a variablefirst. (Click on one)."
    IDP_NOSEARCHSTR         "You haven't given a search string yet."
    IDP_NOTFOUND            "Search string not found."
    IDP_XBENQ_PASSREQ       "You need to supply a password to log in to the server."
    IDP_XBENQ_BADPASSWD     "The supplied password is incorrect."
    IDP_XBENQ_UNKNOWN       "Unknown problem obtaining user data from server."
    IDP_XBENQ_BADCLIENT     "This is an unknown client user or host name. Please check that the /etc/Xibatch-hosts file is correct on the server."
    IDP_XBENQ_UNKNOWNU      "Unable to identify user on server. Please check the windows user name and also the user name(s) in the /etc/Xibatch-hosts file."
    IDP_XBENQ_UNKNOWNG      "Unknown or invalid group. You may be limited to a subset of groups."
    IDP_CONNDIED            "Connection has died to server. Shall I refresh it?"
    IDP_PREVINSTANCE        "Sorry but you are only supposed to have one copy of this program running at once as it uses too many system resources. Please switch to your previous copy."
    IDP_NO_SERVER           "No server is specified in hosts file. Please set one up (using BTRSETW)."
    IDP_NO_HOSTFILE         "There is no hosts file (typically C:\\XIBATCH\\HOSTS). This file should be set up with ""btrsetw"" first."
    IDP_HF_INVALIDHOST      "Unknown or invalid host name in hosts file.\nPlease rerun ""btrsetw""."
END

STRINGTABLE PRELOAD DISCARDABLE 
BEGIN
    AFX_IDS_APP_TITLE       "BTQW - Xi-Batch Queue view for Windows"
    AFX_IDS_IDLEMESSAGE     "For Help, press F1"
    AFX_IDS_HELPMODEMESSAGE "Select an object on which to get Help"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_INDICATOR_EXT        "EXT"
    ID_INDICATOR_CAPS       "CAP"
    ID_INDICATOR_NUM        "NUM"
    ID_INDICATOR_SCRL       "SCRL"
    ID_INDICATOR_OVR        "OVR"
    ID_INDICATOR_REC        "REC"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_APP_ABOUT            "Display program information, version number and copyright\nProgram Version"
    ID_APP_EXIT             "Quit out of btqw"
    ID_HELP_INDEX           "List Help topics"
    ID_HELP_USING           "Display instructions about how to use help"
    ID_CONTEXT_HELP         "Display help for clicked on buttons, menus and windows\nContext Help"
    ID_HELP                 "Display help for current task or command"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_NEXT_PANE            "Switch to the next window pane"
    ID_PREV_PANE            "Switch back to the previous window pane"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_WINDOW_NEW           "Open another window for the active document"
    ID_WINDOW_ARRANGE       "Arrange icons at the bottom of the window"
    ID_WINDOW_CASCADE       "Arrange windows so they overlap"
    ID_WINDOW_TILE_HORZ     "Arrange windows as non-overlapping tiles horizontally"
    ID_WINDOW_TILE_VERT     "Arrange windows as non-overlapping tiles vertically"
    ID_WINDOW_SPLIT         "Split the active window into panes"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_VIEW_TOOLBAR         "Show or hide the toolbar"
    ID_VIEW_STATUS_BAR      "Show or hide the status bar"
END

STRINGTABLE DISCARDABLE 
BEGIN
    AFX_IDS_SCSIZE          "Change the window size"
    AFX_IDS_SCMOVE          "Change the window position"
    AFX_IDS_SCMINIMIZE      "Reduce the window to an icon"
    AFX_IDS_SCMAXIMIZE      "Enlarge the window to full size"
    AFX_IDS_SCNEXTWINDOW    "Switch to the next document window"
    AFX_IDS_SCPREVWINDOW    "Switch to the previous document window"
    AFX_IDS_SCCLOSE         "Close the active window and prompts to save the documents"
END

STRINGTABLE DISCARDABLE 
BEGIN
    AFX_IDS_SCRESTORE       "Restore the window to normal size"
    AFX_IDS_SCTASKLIST      "Activate Task List"
    AFX_IDS_MDICHILD        "Activate this window"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_JOBS_VIEWJOB         "Fetch and display a copy of the job.\nView job"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_WINDOW_NEWJOBWINDOW  "Create a new job display window"
    ID_SEARCH_SEARCHFOR     "Search for specified string"
    ID_SEARCH_SEARCHFORWARD "Repeat last search forwards"
    ID_SEARCH_SEARCHBACKWARDS "Repeat last search backwards"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDR_JOBS                "\nJoblistDoc\nJoblistFile\n(*.xjb)\n.xjb\nJobFileType\nJobFileType"
    IDR_VARS                "\nVarlistDoc\nVarlistFile\n(*.xvr)\n.xvr\nVarlistFileType\nVarlistFileType"
    IDR_VIEWJOB             "\nJdataDocType\nJdataFileType\n(*.xjd)\n.xjd\nJdataFileType\nJDataFileType"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_JANUARY             "January"
    IDS_FEBRUARY            "February"
    IDS_MARCH               "March"
    IDS_APRIL               "April"
    IDS_MAY                 "May"
    IDS_JUNE                "June"
    IDS_JULY                "July"
    IDS_AUGUST              "August"
    IDS_SEPTEMBER           "September"
    IDS_OCTOBER             "October"
    IDS_NOVEMBER            "November"
    IDS_DECEMBER            "December"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_SUNDAY              "Sunday"
    IDS_MONDAY              "Monday"
    IDS_TUESDAY             "Tuesday"
    IDS_WEDNESDAY           "Wednesday"
    IDS_THURSDAY            "Thursday"
    IDS_FRIDAY              "Friday"
    IDS_SATURDAY            "Saturday"
    IDS_SUN                 "Sun"
    IDS_MON                 "Mon"
    IDS_TUE                 "Tue"
    IDS_WED                 "Wed"
    IDS_THUR                "Thur"
    IDS_FRI                 "Fri"
    IDS_SAT                 "Sat"
    IDS_Hday                "Hol"
    IDS_DELETE              "Delete"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_RETAIN              "Retain"
    IDS_MINUTES             "Mins"
    IDS_HOURS               "Hours"
    IDS_DAYS                "Days"
    IDS_WEEKS               "Weeks"
    IDS_MONTHSB             "MonthsB"
    IDS_MONTHSE             "MonthsE"
    IDS_YEARS               "Years"
    IDS_LOTSCONDS           "***COND***"
    IDS_LOTSASSES           "***ASS***"
    IDS_REMRUNNABLE         "Remrun"
    IDS_EXPORT              "Export"
    IDS_CLUSTER             "Cluster"
    IDS_PROG_NONE           " "
    IDS_PROG_DONE           "Done"
    IDS_PROG_ERROR          "Error"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_FILE_PROGRAMOPTIONS  "Set options for program\nProgram Options"
    ID_WINDOW_WINDOWOPTIONS "Select view options for window\nWindow Options"
    ID_ACTION_DELETEJOB     "Delete the job (prompt if options set)\nDelete job"
    ID_ACTION_PERMISSIONS   "Set the permissions and ownership for the currently-selected job or variable"
    ID_ACTION_TITLEPRILOADLEV 
                            "Set the title, priority and loadlevel for the currently-selected job\nTitle/Pri/Loadl"
    ID_ACTION_SETRUNNABLE   "Set job runnable\nSet runnable"
    ID_ACTION_SETCANCELLED  "Set job cancelled\nSet cancelled"
    ID_ACTION_FORCERUN      "Force job to be run ignoring time\nForce run"
    ID_ACTION_KILLJOB       "Send interrupt signal to currently-selected job\nKill job"
    ID_JOBS_TIME            "Set job time and repeat options\nSet job time"
    ID_JOBS_PROCPARAM       "Select directory, umask, ulimit, exit code options"
    ID_JOBS_MAIL            "Set job mail / write options"
    ID_JOBS_ARGUMENTS       "Set job arguments"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_HF_BADTIMEOUT       "Invalid timeout entry in hosts file.\nPlease re-run ""btrsetw"" and retry."
    IDP_HF_NOALIAS          "Your hosts file specifies a host as an internet address (e.g. 192.10.2.3), but you have given no alias.\nPlease re-run ""sprsetw"" to fix."
    IDP_SK_CCLISTSOCK       "Cannot create ""listen"" socket - aborting."
    IDP_SK_CCPROBESOCK      "Cannot create ""probe"" socket - aborting."
    IDP_GBTU_NOBIND         "Unable to bind UDP socket to access user details. Please reboot machine."
    IDP_GBTU_NOSEND         "Send failure on UDP socket for accessing user details from server. Please reboot this machine."
    IDP_GBTU_NORECV         "Receive failure obtaining user details from Unix host. Is ""xbnetserv"" running?"
    IDP_GBTU_NVALID         "Invalid user details returned from Unix Server. Is the ""/etc/Xibatch-hosts"" file set up correctly on the server? This machine should be set up as a DOS client and the appropriate user name included."
    IDP_PROBE_SOCKERR       "Unable to create UDP socket for probe to host. You may need to allocate more TCP/IP buffers."
    IDP_PROBE_BINDERR       "Unable to bind UDP socket for probe to host. You may need to reboot this machine."
    IDP_PROBE_SENDERR       "Failure sending probe. You may need to reboot this machine and/or some or all of your Unix hosts."
    IDP_GBTU_NOSOCK         "Unable to create socket entry for accessing user details - aborting."
    IDP_NOCILIST            "Sorry, cannot get ""command interpreter"" list from server."
    IDP_ASYNCSEL            "Cannot set async messages - messages will not work."
    IDP_LISTASYNCSEL        "Cannot set up asynchronous messages on listening socket. New machines starting up will not be noticed."
    IDP_PROBEASYNCSEL       "Cannot set up asynchronous messages on probe socket. Messages will not be noticed from other machines."
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_CCFEEDSOCKET        "Cannot create TCP socket to fetch file copy - sorry. You may need to configure more TCP slots in your kernel."
    IDP_CCOFEEDSOCKET       "Cannot access host to fetch copy of job over TCP socket - sorry."
    IDP_CSFEEDSOCKET        "Cannot send initial packet on feed socket - sorry"
    IDP_CCTEMPFILE          "Cannot create temporary file to copy remote job into - sorry."
    IDP_CWTEMPFILE          "Cannot write temporary file for remote job - is file system full?"
    IDP_NOMEMFORJOB         "There is no memory available for the page buffers for this job - sorry"
    IDP_INVALIDDOC          "Sorry - document is not valid - cannot display"
    IDP_JOBTOOWIDE          "Sorry but your job has too long lines to be scrolled under Windows."
    IDP_JOBTOOLONG          "Sorry but your job has too many lines to be scrolled through under windows."
    IDP_CONFDELJ            "Are you sure that you want to delete this job?"
    IDP_JDNOSEARCHS         "No search string specified (yet)."
    IDP_JDSNOTFOUND         "Unable to find the string in the job text."
    IDP_JPNOSEARCHS         "No string specified - please select one first."
    IDP_JPNOITEM            "You have turned off all items in the attributes to look for. You must specify one."
    IDP_SYSM_NOPERM         "The last operation was rejected as you do not have the required permission. (Sorry I didn't notice this before, or maybe it's just been changed)."
    IDP_JOBM_OK             "The last job operation ran ok. This message should not have appeared."
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_JOBM_NEXIST         "The last job you applied an operation to no longer exists. Maybe someone else deleted it. "
    IDP_JOBM_VNEXIST        "One of the variables in your job no longer exists. Maybe it got deleted just as you added it."
    IDP_JOBM_NOPERM         "Sorry but you do not have the permissions to do the last operation on the job you selected."
    IDP_JOBM_VNOPERM        "Sorry but you do not have the required access to one or more variables affected by your job."
    IDP_JOBM_NOPRIV         "Sorry but you do not have the privilege to perform the requested information."
    IDP_JOBM_SYSVAR         "Sorry but your job assigns a read-only system variable."
    IDP_JOBM_SYSVTYPE       "Sorry but your job incorrectly assigns a wrong type to a system variable."
    IDP_JOBM_FULLUP         "Sorry but your host cannot accomodate a new job as the limit on shared memory has been reached."
    IDP_JOBM_ISRUNNING      "Job is running - too late to perform last operation."
    IDP_JOBM_REMVINLOCJ     "Local-only job refers to exported variable."
    IDP_JOBM_LOCVINREMJ     "Exported job refers to local variable."
    IDP_JOBM_MINPRIV        "You have attempted to reduce the permissions of the job to below the minimum."
    IDP_VARM_OK             "The last variable operation ran ok. This message should not have appeared."
    IDP_VARM_EXISTS         "The variable already exists. You cannot create a new one."
    IDP_VARM_NEXISTS        "The last variable invoked does not exist. Maybe someone just deleted it."
    IDP_VARM_CLASHES        "The variable clashes with an existing variable (this could be because you just widened the mode)."
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_JOBS_ENVIRONMENT     "Set environment variables for job"
    ID_JOBS_REDIRECTIONS    "Set I/O redirection parameters for job"
    ID_CONDITIONS_JOBCONDITIONS "Set job dependency conditions\nConditions"
    ID_CONDITIONS_JOBASSIGNMENTS 
                            "Set job assignments at start/end of job\nAssignments"
    ID_VARS_INCREMENT       "Increment variable by amount of constant"
    ID_VARIABLES_ASSIGN     "Assign value to variable\nAssign variable"
    ID_VARIABLES_INCREMENT  "Increment variable by constant amount\nIncrement Var"
    ID_VARIABLES_DECREMENT  "Decrement variable by constant amount\nDecrement var"
    ID_VARIABLES_MULTIPLY   "Multiply variable by constant amount"
    ID_VARIABLES_DIVIDE     "Divide variable by constant amount"
    ID_VARIABLES_REMAINDER  "Take modulus of variable by constant amount"
    ID_VARIABLES_SETCONSTANT "Set constant amount"
    ID_VARIABLES_SETCOMMENT "Set comment field on variable"
    ID_ACTION_QUITJOB       "Send quit signal to currently-selected job\nQuit (core dump)"
    ID_ACTION_OTHERSIGNAL   "Send other kill signal to currently-selected job"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_FILE_SAVEFILE        "Save current options to file\nSave Options"
    ID_ACTION_GOJOB         "Start job now - advancing time.\nForce & adv time"
    ID_JOBS_ADVANCETIME     "Move time onto next without running job\nAdvance time"
    ID_FILE_TIMEDEFAULTS    "Set up default options for time setting."
    ID_FILE_CONDITIONDEFAULTS "Set up default options for conditions."
    ID_FILE_ASSIGNMENTDEFAULTS "Set up default options for assignments."
    ID_JOBS_UNQUEUEJOB      "Copy job to file with batch command to restore"
    ID_JOBS_COPYJOB         "As unqueue, but do not delete job"
    ID_JOBS_COPYOPTIONSINJOB "Make options in job default for future jobs"
    ID_WINDOW_JOBDISPLAYFORMAT "Set format of job list display"
    ID_WINDOW_VARDISPLAYFMTLINE1 "Set format of variable window"
    ID_WINDOW_JOBLISTFONT   "Select font for job list display"
    ID_WINDOW_JOBDATALISTFONT "Select font for list of job data"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_VARM_NOPERM         "You do not have permission to do the last operation on the variable."
    IDP_VARM_NOPRIV         "You do not have the required privilege to perform the requested operation."
    IDP_VARM_SYNC           "Conflict with another user on variable assignment. Please try again."
    IDP_VARM_SYSVAR         "Attempt to assign a read-only system variable."
    IDP_VARM_SYSVTYPE       "Attempt to assign the wrong type to a system variable."
    IDP_VARM_FULLUP         "Cannot accomodate any more variables as the host's shared memory space is full."
    IDP_VARM_DSYSVAR        "You cannot delete a system variable."
    IDP_VARM_INUSE          "Variable in use - cannot delete"
    IDP_VARM_MINPRIV        "You have attempted to reduce the permissions of the variable to below the minimum."
    IDP_VARM_DELREMOTE      "Attempt to delete a remote variable."
    IDP_VARM_UNKREMUSER     "Unknown remote user."
    IDP_VARM_UNKREMGRP      "Unknown remote group."
    IDP_VARM_RENEXISTS      "Renaming variable - clashes with existing."
    IDP_NETM_OK             "The last network operation ran ok. This message should not have appeared."
    IDP_NETM_LOCKNONE       "The last network lock operation ran ok. This message should not have appeared."
    IDP_NETM_LOCKOK         "The last network lock operation ran ok. This message should not have appeared."
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_NETM_LOCKPRIO       "The last network lock operation ran ok. This message should not have appeared."
    IDP_NETM_NOFORK         "The last network operation failed as there are too many processes running on the Unix host."
    IDP_NETM_NBADMSGQ       "The last network operation failed as the IPC message queue is full on the Unix host."
    IDP_NETM_NTIMEOUT       "The last network operation failed due to a network timeout."
    IDP_NETM_HOSTOFFLINE    "The last network operation failed as the host is offline."
    IDP_NETM_HOSTDIED       "The last network operation failed as the host went offline."
    IDP_NETM_CONNFAIL       "The last network operation failed as the host connection failed."
    IDP_NOTPERM             "You are not permitted to do the requested operation on the specified job."
    IDP_JRUNNING            "Sorry but the job is running and you cannot change it in the way you want whilst it is running."
    IDP_NOTIMETOADV         "No repeat specification to advance the time with."
    IDP_NOTALLDAYS          "You cannot set every day of the week to avoid!"
    IDP_TOOMANYCONDS        "Too many conditions in job."
    IDP_NOCVARSEL           "No condition variable selected to edit."
    IDP_NOCVALUE            "No value in condition."
    IDP_TOOMANYASSES        "Too many assignments in job."
    IDP_NOAFLAGSSET         "No assignment flags are set."
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_NOAVARSEL           "No assignment variable selected."
    IDP_NOAVALUE            "No assignment value provided."
    IDP_NORMBADRANGE        "Bad range given for normal exit codes."
    IDP_ERRBADRANGE         "Bad range given for error exit codes."
    IDP_NOFILENAME          "No file name given in redirection."
    IDP_JLTMINMODE          "The proposed new modes are less than the minimum to enable anyone to do anything."
    IDP_VLTMINMODE          "The proposed new modes are less than the minimum to enable anyone to do anything."
    IDP_VNOTPERM            "You are not permitted to do the requested operation on the specified variable."
    IDP_NOTARITHVAR         "Variable does not have numeric value to perform the arithmetic operation upon."
    IDP_VNOTFOUND           "Variable not found."
    IDP_CONSTDIVZERO        "Attempt to divide variable value by zero."
    IDP_NOVVALUE            "No value given for assignment."
    IDP_CCJOBQFILE          "Cannot create job queue file. (This is the copy of the job file)."
    IDP_CWJOBQFILE          "Cannot write job queue file. (This is the file used to hold a copy of the job file)."
    IDP_CWBATFILE           "Trouble writing batch file. This is the .bat file containing the ""btr"" command to re-invoke the job."
    IDP_CDJOBQFILE          "Cannot delete job queue file pending abort or other error - sorry."
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_PROG_ABORTED        "Abort"
    IDS_PROG_CANCELLED      "Canc"
    IDS_PROG_STARTUP1       "Init"
    IDS_PROG_STARTUP2       "Start"
    IDS_PROG_RUNNING        "Run"
    IDS_PROG_FINISHED       "Fin"
    IDS_CONDOP              " "
    IDS_CEQ                 "="
    IDS_CNE                 "!="
    IDS_CLT                 "<"
    IDS_CLE                 "<="
    IDS_CGT                 ">"
    IDS_CGE                 ">="
    IDS_ASSOP               " "
    IDS_AASSIGN             "="
    IDS_AINCR               "+="
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_ADECR               "-="
    IDS_AMULT               "*="
    IDS_ADIV                "/="
    IDS_AMOD                "%="
    IDS_AEXIT               "exit"
    IDS_ASIGNAL             "sig"
    IDS_STDIN_NAME          "(stdin)"
    IDS_STDOUT_NAME         "(stdout)"
    IDS_STDERR_NAME         "(stderr)"
    IDS_UNKNOWNCI           "*Unknown*"
    IDS_DEF_JFMT            "%12N %7U %13H %14I %3p %5L %5t %9c %<4P"
    IDS_DEF_V1FMT           "%12N %10V %6E %20C %6U"
    IDS_EDITINGJFMT         "Job list display format"
    IDS_EDITINGV1FMT        "Variable list display format"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDP_CRMSGFILE           "Cannot read message file for ""btr""."
    IDP_ARGDEFERRS          "Errors in argument definitions in ""btr"" option defaults."
    IDP_NOCODESEL           "You didn't select a format code. Please try again."
    IDP_TOOMANYFMTS         "Too many format codes - sorry"
    IDP_SAVEPROPTS          "Save program options before exit?"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_JFORMAT_A           "Arguments to job"
    IDS_JFORMAT_C           "Conditions for job in full"
    IDS_JFORMAT_D           "Directory used by job"
    IDS_JFORMAT_E           "Environment table for job"
    IDS_JFORMAT_G           "Group owner of job"
    IDS_JFORMAT_H           "Title of job in full, including queue prefix"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_JFORMAT_I           "Command interpreter name"
    IDS_JFORMAT_L           "Load level"
    IDS_JFORMAT_M           "Mode (permissions) of job"
    IDS_JFORMAT_N           "Job number"
    IDS_JFORMAT_O           "Originating host name"
    IDS_JFORMAT_P           "Progress code for job"
    IDS_JFORMAT_R           "Redirection table for job"
    IDS_JFORMAT_S           "Job assignments in full"
    IDS_JFORMAT_T           "Time and date in full"
    IDS_JFORMAT_U           "Name of job owner"
    IDS_JFORMAT_W           "Time according to process state."
    IDS_JFORMAT_X           "Exit code ranges"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_JFORMAT_aa          "Days to avoid"
    IDS_JFORMAT_bb          "Start time of job."
    IDS_JFORMAT_cc          "Conditions (variable names only)"
    IDS_JFORMAT_dd          "Delete time - hours after job run."
    IDS_JFORMAT_ee          "Export status marker"
    IDS_JFORMAT_ff          "End time of job"
    IDS_JFORMAT_gg          "Grace time for job to wind down after run time."
    IDS_JFORMAT_hh          "Job title, excluding queue name"
    IDS_JFORMAT_ii          "Process id (on host running job) and if appropriate"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_JFORMAT_kk          "Signal number to automatically kill job after maximum run time."
    IDS_JFORMAT_ll          "Maximum run time for job."
    IDS_JFORMAT_mm          "Umask values"
    IDS_JFORMAT_nn          "Sequence number"
    IDS_JFORMAT_oo          "Original time/date job submitted."
    IDS_JFORMAT_pp          "Priority"
    IDS_JFORMAT_qq          "Queue name"
    IDS_JFORMAT_rr          "Repeat options"
    IDS_JFORMAT_ss          "Assignments - names of vars only"
    IDS_JFORMAT_tt          "Time or date if > 24 hours away"
    IDS_JFORMAT_uu          "Ulimit value"
    IDS_JFORMAT_xx          "Last exit code of job"
    IDS_JFORMAT_yy          "Signal number job halted with."
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_VFORMAT_C           "Comment string for variable"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_VFORMAT_E           "Export marker"
    IDS_VFORMAT_G           "Group owner of variable"
    IDS_VFORMAT_K           "Cluster marker"
    IDS_VFORMAT_M           "Mode (permissions) of variable"
    IDS_VFORMAT_N           "Name of variable"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_VFORMAT_U           "Owner of variable"
    IDS_VFORMAT_V           "Value of variable"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_JOBS_INVOKEBTRW      "Invoke BTRW to create jobs."
    ID_JOBS_TIMELIMITS      "Set delete time and maximum run time for job."
    ID_FILE_NETWORKSTATS    "Check status of network connections."
    ID_FILE_USERPERMS       "DIsplay user permissions"
    ID_WINDOW_SAVEWIDTHSASDEFAULT 
                            "Save currently selected widths as default widths"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_SJFORMAT_A          "Args"
    IDS_SJFORMAT_C          "Conditions"
    IDS_SJFORMAT_D          "Dir"
    IDS_SJFORMAT_E          "Environ"
    IDS_SJFORMAT_G          "Grp"
    IDS_SJFORMAT_H          "Title"
    IDS_SJFORMAT_I          "CmdI"
    IDS_SJFORMAT_L          "Llev"
    IDS_SJFORMAT_M          "Mode"
    IDS_SJFORMAT_N          "Jnum"
    IDS_SJFORMAT_O          "Ohost"
    IDS_SJFORMAT_P          "Prog"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_SJFORMAT_R          "I/O"
    IDS_SJFORMAT_S          "Assignments"
    IDS_SJFORMAT_T          "Time/date"
    IDS_SJFORMAT_U          "User"
    IDS_SJFORMAT_W          "Ntime"
    IDS_SJFORMAT_X          "Exits"
    IDS_SJFORMAT_aa         "Avoid"
    IDS_SJFORMAT_bb         "Stime"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_SJFORMAT_cc         "Cond"
    IDS_SJFORMAT_dd         "Delt"
    IDS_SJFORMAT_ee         "Exp"
    IDS_SJFORMAT_ff         "Endt"
    IDS_SJFORMAT_gg         "Grace"
    IDS_SJFORMAT_hh         "Tit"
    IDS_SJFORMAT_ii         "Pid"
    IDS_SJFORMAT_kk         "Ksig"
    IDS_SJFORMAT_ll         "Runt"
    IDS_SJFORMAT_mm         "Umk"
    IDS_SJFORMAT_nn         "Sq"
    IDS_SJFORMAT_oo         "Ctm"
    IDS_SJFORMAT_pp         "Pr"
    IDS_SJFORMAT_qq         "Queue"
    IDS_SJFORMAT_rr         "Rep"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_SJFORMAT_ss         "Ass"
    IDS_SJFORMAT_tt         "Tim"
    IDS_SJFORMAT_uu         "Ulm"
    IDS_SJFORMAT_xx         "Xit"
    IDS_SJFORMAT_yy         "Sg"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_SVFORMAT_C          "Cmt"
    IDS_SVFORMAT_E          "Exp"
    IDS_SVFORMAT_G          "Grp"
    IDS_SVFORMAT_K          "Clst"
END

STRINGTABLE DISCARDABLE 
BEGIN
    IDS_SVFORMAT_M          "Mode"
    IDS_SVFORMAT_N          "Name"
    IDS_SVFORMAT_U          "User"
    IDS_SVFORMAT_V          "Value"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_FILE_JOBCOLOURS      "Set up default job colours\nSet up job colours"
    ID_JCOLOUR_READY        "Colour if job ready to run\nJob ready colour"
    ID_JCOLOUR_STARTUP      "Colour if job is starting up\nStartup Colour"
    ID_JCOLOUR_RUNNING      "Colour if job is running\nJob running colour"
    ID_JCOLOUR_FINISHED     "Colour if job has finished (OK)\nFinished colour"
END

STRINGTABLE DISCARDABLE 
BEGIN
    ID_JCOLOUR_CANCELLED    "Job is in cancelled state\nCancelled colour"
    ID_JCOLOUR_ERROR        "Job has given error exit\nError exit colour"
    ID_JCOLOUR_ABORT        "Colour to indicate job has aborted\nJob abort colour"
    ID_WJCOLOUR_READY       "Colour if job ready to run\nJob ready colour"
    ID_WJCOLOUR_CANCELLED   "Job is in cancelled state\nCancelled colour"
    ID_WJCOLOUR_RUNNING     "Colour if job is running\nJob running colour"
    ID_WJCOLOUR_STARTUP     "Colour if job is starting up\nStartup Colour"
    ID_WJCOLOUR_FINISHED    "Colour if job has finished (OK)\nFinished colour"
    ID_WJCOLOUR_ERROR       "Job has given error exit\nError exit colour"
    ID_WJCOLOUR_ABORT       "Colour to indicate job has aborted\nJob abort colour"
    ID_FILE_JCOLOUR_COPYTOPROG 
                            "Copy window colour scheme to BTQW defaults\nCopy to defaults"
    ID_FILE_JCOLOUR_COPYTOWIN 
                            "Copy current application default colours to window\nCopy to window"
END

#endif    // English (U.K.) resources
/////////////////////////////////////////////////////////////////////////////



#ifndef APSTUDIO_INVOKED
/////////////////////////////////////////////////////////////////////////////
//
// Generated from the TEXTINCLUDE 3 resource.
//
#include "res\btqw.rc2"  // non-App Studio edited resources

#include "afxres.rc"  // Standard components

/////////////////////////////////////////////////////////////////////////////
#endif    // not APSTUDIO_INVOKED

